@@ -2,19 +2,19 @@ from datetime import date, datetime, time, timedelta
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type, Union, cast
 
-from starlette.middleware.cors import CORSMiddleware
-from starlette.middleware.trustedhost import TrustedHostMiddleware
 from typing_extensions import TypedDict
 
 from starlite.asgi import ASGIRouter
 from starlite.asgi.utils import get_route_handlers, wrap_in_exception_handler
-from starlite.config import AppConfig, CacheConfig, OpenAPIConfig
+from starlite.config import AllowedHostsConfig, AppConfig, CacheConfig, OpenAPIConfig
 from starlite.config.logging import get_logger_placeholder
 from starlite.connection import Request, WebSocket
 from starlite.datastructures.state import State
 from starlite.exceptions import NoRouteMatchFoundException
 from starlite.handlers.http import HTTPRouteHandler
+from starlite.middleware.allowed_hosts import AllowedHostsMiddleware
 from starlite.middleware.compression import CompressionMiddleware
+from starlite.middleware.cors import CORSMiddleware
 from starlite.router import Router
 from starlite.routes import ASGIRoute, HTTPRoute, WebSocketRoute
 from starlite.signature import SignatureModelFactory
@@ -80,8 +80,7 @@ DEFAULT_CACHE_CONFIG = CacheConfig()
 
 
 class HandlerIndex(TypedDict):
-    """This class is used to map route handler names to a mapping of paths +
-    route handler.
+    """Map route handler names to a mapping of paths + route handler.
 
     It's returned from the 'get_handler_index_by_name' utility method.
     """
@@ -95,6 +94,14 @@ class HandlerIndex(TypedDict):
 
 
 class Starlite(Router):
+    """The Starlite application.
+
+    `Starlite` is the root level of the app - it has the base path of "/" and all root level
+    Controllers, Routers and Route Handlers should be registered on it.
+
+    Inherits from the [Router][starlite.router.Router] class
+    """
+
     __slots__ = (
         "after_exception",
         "after_shutdown",
@@ -135,7 +142,7 @@ class Starlite(Router):
         after_response: Optional["AfterResponseHookHandler"] = None,
         after_shutdown: Optional["SingleOrList[LifeSpanHookHandler]"] = None,
         after_startup: Optional["SingleOrList[LifeSpanHookHandler]"] = None,
-        allowed_hosts: Optional[List[str]] = None,
+        allowed_hosts: Optional[Union[List[str], "AllowedHostsConfig"]] = None,
         before_request: Optional["BeforeRequestHookHandler"] = None,
         before_send: Optional["SingleOrList[BeforeMessageSendHookHandler]"] = None,
         before_shutdown: Optional["SingleOrList[LifeSpanHookHandler]"] = None,
@@ -169,12 +176,7 @@ class Starlite(Router):
         template_config: Optional["TemplateConfig"] = None,
         websocket_class: Optional[Type["WebSocket"]] = None,
     ) -> None:
-        """The Starlite application.
-
-        `Starlite` is the root level of the app - it has the base path of "/" and all root level
-        Controllers, Routers and Route Handlers should be registered on it.
-
-        It inherits from the [Router][starlite.router.Router] class.
+        """Initialize a `Starlite` application.
 
         Args:
             after_exception: An application level [exception hook handler][starlite.types.AfterExceptionHookHandler]
@@ -300,10 +302,10 @@ class Starlite(Router):
         for handler in on_app_init or []:
             config = handler(config)
 
+        self.allowed_hosts = cast("Optional[AllowedHostsConfig]", config.allowed_hosts)
         self.after_exception = as_async_callable_list(config.after_exception)
         self.after_shutdown = as_async_callable_list(config.after_shutdown)
         self.after_startup = as_async_callable_list(config.after_startup)
-        self.allowed_hosts = config.allowed_hosts
         self.before_send = as_async_callable_list(config.before_send)
         self.before_shutdown = as_async_callable_list(config.before_shutdown)
         self.before_startup = as_async_callable_list(config.before_startup)
@@ -370,7 +372,7 @@ class Starlite(Router):
         receive: Union["Receive", "LifeSpanReceive"],
         send: Union["Send", "LifeSpanSend"],
     ) -> None:
-        """The application entry point.
+        """Application entry point.
 
         Lifespan events (startup / shutdown) are sent to the lifespan handler, otherwise the ASGI handler is used
 
@@ -390,8 +392,9 @@ class Starlite(Router):
         await self.asgi_handler(scope, receive, self._wrap_send(send=send, scope=scope))  # type: ignore[arg-type]
 
     def register(self, value: "ControllerRouterHandler") -> None:  # type: ignore[override]
-        """Registers a route handler on the app. This method can be used to
-        dynamically add endpoints to an application.
+        """Register a route handler on the app.
+
+        This method can be used to dynamically add endpoints to an application.
 
         Args:
             value: an instance of [Router][starlite.router.Router], a subclasses of
@@ -424,9 +427,8 @@ class Starlite(Router):
         self.asgi_router.construct_routing_trie()
 
     def get_handler_index_by_name(self, name: str) -> Optional[HandlerIndex]:
-        """Receives a route handler name and returns an optional dictionary
-        containing the route handler instance and list of paths sorted
-        lexically.
+        """Receives a route handler name and returns an optional dictionary containing the route handler instance and
+        list of paths sorted lexically.
 
         Examples:
             ```python
@@ -461,8 +463,8 @@ class Starlite(Router):
         return HandlerIndex(handler=handler, paths=paths, identifier=identifier)
 
     def route_reverse(self, name: str, **path_parameters: Any) -> str:
-        """Receives a route handler name, path parameter values and returns url
-        path to the handler with filled path parameters.
+        """Receives a route handler name, path parameter values and returns url path to the handler with filled path
+        parameters.
 
         Examples:
             ```python
@@ -526,8 +528,7 @@ class Starlite(Router):
         return join_paths(output)
 
     def url_for_static_asset(self, name: str, file_path: str) -> str:
-        """Receives a static files handler name, an asset file path and returns
-        resolved url path to the asset.
+        """Receives a static files handler name, an asset file path and returns resolved url path to the asset.
 
         Examples:
             ```python
@@ -565,9 +566,10 @@ class Starlite(Router):
 
     @property
     def route_handler_method_view(self) -> Dict[str, List[str]]:
-        """
+        """Map route handlers to paths.
+
         Returns:
-            A dictionary mapping route handlers to paths.
+            A dictionary of router handlers and lists of paths as strings
         """
         route_map: Dict[str, List[str]] = {}
         for handler, routes in self.asgi_router.route_mapping.items():
@@ -576,26 +578,23 @@ class Starlite(Router):
         return route_map
 
     def _create_asgi_handler(self) -> "ASGIApp":
-        """Creates an ASGIApp that wraps the ASGI router inside an exception
-        handler.
+        """Create an ASGIApp that wraps the ASGI router inside an exception handler.
 
-        If CORS or TrustedHost configs are provided to the constructor,
-        they will wrap the router as well.
+        If CORS or TrustedHost configs are provided to the constructor, they will wrap the router as well.
         """
         asgi_handler: "ASGIApp" = self.asgi_router
         if self.compression_config:
             asgi_handler = CompressionMiddleware(app=asgi_handler, config=self.compression_config)
         if self.allowed_hosts:
-            asgi_handler = TrustedHostMiddleware(app=asgi_handler, allowed_hosts=self.allowed_hosts)  # type: ignore
+            asgi_handler = AllowedHostsMiddleware(app=asgi_handler, config=self.allowed_hosts)
         if self.cors_config:
-            asgi_handler = CORSMiddleware(app=asgi_handler, **self.cors_config.dict())  # type: ignore
+            asgi_handler = CORSMiddleware(app=asgi_handler, config=self.cors_config)
         return wrap_in_exception_handler(
             debug=self.debug, app=asgi_handler, exception_handlers=self.exception_handlers or {}
         )
 
     def _create_handler_signature_model(self, route_handler: "BaseRouteHandler") -> None:
-        """Creates function signature models for all route handler functions
-        and provider dependencies."""
+        """Create function signature models for all route handler functions and provider dependencies."""
         if not route_handler.signature_model:
             route_handler.signature_model = SignatureModelFactory(
                 fn=cast("AnyCallable", route_handler.fn),
@@ -611,7 +610,7 @@ class Starlite(Router):
                 ).create_signature_model()
 
     def _wrap_send(self, send: "Send", scope: "Scope") -> "Send":
-        """Wraps the ASGI send and handles any 'before send' hooks.
+        """Wrap the ASGI send and handles any 'before send' hooks.
 
         Args:
             send: The ASGI send function.
