@@ -31,6 +31,11 @@ if TYPE_CHECKING:
 
 
 class ASGIRouter:
+    """Starlite ASGI router.
+
+    Handling both the ASGI lifespan events and routing of connection requests.
+    """
+
     __slots__ = (
         "_plain_routes",
         "_registered_routes",
@@ -40,12 +45,8 @@ class ASGIRouter:
         "route_mapping",
     )
 
-    def __init__(
-        self,
-        app: "Starlite",
-    ) -> None:
-        """This class is the Starlite ASGI router. It handles both the ASGI
-        lifespan event and routing connection requests.
+    def __init__(self, app: "Starlite") -> None:
+        """Initialize `ASGIRouter`.
 
         Args:
             app: The Starlite app instance
@@ -58,7 +59,10 @@ class ASGIRouter:
         self.route_mapping: Dict[str, List["BaseRoute"]] = defaultdict(list)
 
     async def __call__(self, scope: "Scope", receive: "Receive", send: "Send") -> None:
-        """The main entry point to the Router class."""
+        """ASGI callable.
+
+        The main entry point to the Router class.
+        """
         asgi_app, handler = parse_scope_to_route(
             root_node=self.root_route_map_node, scope=scope, plain_routes=self._plain_routes
         )
@@ -66,8 +70,7 @@ class ASGIRouter:
         await asgi_app(scope, receive, send)
 
     def _store_handler_to_route_mapping(self, route: "BaseRoute") -> None:
-        """Stores the mapping of route handlers to routes and to route handler
-        names.
+        """Store the mapping of route handlers to routes and to route handler names.
 
         Args:
             route: A Route instance.
@@ -86,12 +89,11 @@ class ASGIRouter:
             self.route_handler_index[identifier] = handler
 
     async def _call_lifespan_handler(self, handler: "LifeSpanHandler") -> None:
-        """Determines whether the lifecycle handler expects an argument, and if
-        so passes the `app.state` to it. If the handler is an async function,
-        it awaits the return.
+        """Determine whether the lifecycle handler expects an argument, and if so pass the `app.state` to it. If the
+        handler is an async function, await the return.
 
         Args:
-            handler (LifeSpanHandler): sync or async callable that may or may not have an argument.
+            handler: sync or async callable that may or may not have an argument.
         """
         async_callable = AsyncCallable(handler)  # type: ignore
 
@@ -123,8 +125,7 @@ class ASGIRouter:
         validate_node(node=self.root_route_map_node)
 
     async def lifespan(self, receive: "LifeSpanReceive", send: "LifeSpanSend") -> None:
-        """Handles the ASGI "lifespan" event on application startup and
-        shutdown.
+        """Handle the ASGI "lifespan" event on application startup and shutdown.
 
         Args:
             receive: The ASGI receive function.
@@ -164,12 +165,10 @@ class ASGIRouter:
             await send(shutdown_event)
 
     async def startup(self) -> None:
-        """Run any [LifeSpanHandlers][starlite.types.LifeSpanHandler] defined
-        in the application's `.on_startup` list.
+        """Run any [LifeSpanHandlers][starlite.types.LifeSpanHandler] defined in the application's `.on_startup` list.
 
-        Calls the `before_startup` hook and `after_startup` hook
-        handlers respectively before and after calling in the lifespan
-        handlers.
+        Calls the `before_startup` hook and `after_startup` hook handlers respectively before and after calling in the
+        lifespan handlers.
         """
         for hook in self.app.before_startup:
             await hook(self.app)
@@ -181,14 +180,11 @@ class ASGIRouter:
             await hook(self.app)
 
     async def shutdown(self) -> None:
-        """Run any [LifeSpanHandlers][starlite.types.LifeSpanHandler] defined
-        in the application's `.on_shutdown` list.
+        """Run any [LifeSpanHandlers][starlite.types.LifeSpanHandler] defined in the application's `.on_shutdown` list.
 
-        Calls the `before_shutdown` hook and `after_shutdown` hook
-        handlers respectively before and after calling in the lifespan
-        handlers.
+        Calls the `before_shutdown` hook and `after_shutdown` hook handlers respectively before and after calling in the
+        lifespan handlers.
         """
-
         for hook in self.app.before_shutdown:
             await hook(self.app)
 
