@@ -22,8 +22,7 @@ def add_map_route_to_trie(
     route: Union["HTTPRoute", "WebSocketRoute", "ASGIRoute"],
     plain_routes: Set[str],
 ) -> "RouteTrieNode":
-    """Adds a new route path (e.g. '/foo/bar/{param:int}') into the route_map
-    tree.
+    """Add a new route path (e.g. '/foo/bar/{param:int}') into the route_map tree.
 
     Inserts non-parameter paths ('plain routes') off the tree's root
     node. For paths containing parameters, splits the path on '/' and
@@ -42,7 +41,7 @@ def add_map_route_to_trie(
     current_node = root_node
     path = route.path
 
-    is_mount = hasattr(route, "route_handler") and getattr(route.route_handler, "is_mount", False)  # type: ignore[union-attr]
+    is_mount = hasattr(route, "route_handler") and getattr(route.route_handler, "is_mount", False)  # pyright: ignore
 
     if not (route.path_parameters or is_mount):
         plain_routes.add(path)
@@ -99,7 +98,6 @@ def configure_node(
                 asgi_app=build_route_middleware_stack(app=app, route=route, route_handler=handler),
                 handler=handler,
             )
-
     elif isinstance(route, WebSocketRoute):
         node["asgi_handlers"]["websocket"] = ASGIHandlerTuple(
             asgi_app=build_route_middleware_stack(app=app, route=route, route_handler=route.route_handler),
@@ -121,8 +119,7 @@ def build_route_middleware_stack(
     route: Union["HTTPRoute", "WebSocketRoute", "ASGIRoute"],
     route_handler: "RouteHandlerType",
 ) -> "ASGIApp":
-    """Constructs a middleware stack that serves as the point of entry for each
-    route.
+    """Construct a middleware stack that serves as the point of entry for each route.
 
     Args:
         app: The Starlite app instance.
