@@ -1,9 +1,8 @@
-from typing import TYPE_CHECKING, Dict, List, NamedTuple, Set, Type, Union
+from typing import TYPE_CHECKING, Dict, List, Literal, NamedTuple, Set, Type, Union
 
 from typing_extensions import TypedDict
 
 if TYPE_CHECKING:
-    from typing_extensions import Literal
 
     from starlite.types import ASGIApp, Method, RouteHandlerType
     from starlite.types.internal_types import PathParameterDefinition
@@ -14,7 +13,7 @@ class PathParameterSentinel:
 
 
 class ASGIHandlerTuple(NamedTuple):
-    """This class encapsulates a route handler node."""
+    """Encapsulation of a route handler node."""
 
     asgi_app: "ASGIApp"
     """An ASGI stack, composed of a handler function and layers of middleware that wrap it."""
@@ -23,9 +22,9 @@ class ASGIHandlerTuple(NamedTuple):
 
 
 class RouteTrieNode(TypedDict):
-    """This class represents a radix trie node."""
+    """A radix trie node."""
 
-    asgi_handlers: Dict[Union["Method", "Literal['websocket', 'asgi']"], "ASGIHandlerTuple"]
+    asgi_handlers: Dict[Union["Method", Literal["websocket", "asgi"]], "ASGIHandlerTuple"]
     """
     A mapping of ASGI handlers stored on the node.
     """
@@ -33,7 +32,7 @@ class RouteTrieNode(TypedDict):
     """
     A set containing the child keys, same as the children dictionary - but as a set, which offers faster lookup.
     """
-    children: Dict[Union[str, Type[PathParameterSentinel]], "RouteTrieNode"]  # type: ignore[misc]
+    children: Dict[Union[str, Type[PathParameterSentinel]], "RouteTrieNode"]
     """
     A dictionary mapping path components or using the PathParameterSentinel class to child nodes.
     """
@@ -62,7 +61,7 @@ class RouteTrieNode(TypedDict):
 
 
 def create_node() -> "RouteTrieNode":
-    """Creates a RouteMapNode instance.
+    """Create a RouteMapNode instance.
 
     Returns:
         A route map node instance.
