@@ -1,25 +1,16 @@
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Dict,
-    Generic,
-    List,
-    Optional,
-    TypeVar,
-    Union,
-    cast,
-)
-
-from starlette.datastructures import URL, Address, URLPath
+from typing import TYPE_CHECKING, Any, Dict, Generic, Optional, TypeVar, Union, cast
 
 from starlite.datastructures.headers import Headers
+from starlite.datastructures.multi_dicts import QueryMultiDict
 from starlite.datastructures.state import State
+from starlite.datastructures.url import URL, Address, make_absolute_url
 from starlite.exceptions import ImproperlyConfiguredException
-from starlite.parsers import parse_cookie_string, parse_query_params
+from starlite.parsers import parse_cookie_string
 from starlite.types.empty import Empty
 
 if TYPE_CHECKING:
-    from typing import MutableMapping
+
+    from typing import NoReturn
 
     from pydantic import BaseModel
 
@@ -34,8 +25,10 @@ Auth = TypeVar("Auth")
 Handler = TypeVar("Handler")
 
 
-async def empty_receive() -> Any:  # pragma: no cover
-    """Placeholder value.
+async def empty_receive() -> "NoReturn":  # pragma: no cover
+    """Raise a `RuntimeError`.
+
+    Serves as a placeholder `send` function.
 
     Raises:
         RuntimeError
@@ -43,8 +36,10 @@ async def empty_receive() -> Any:  # pragma: no cover
     raise RuntimeError()
 
 
-async def empty_send(_: "Message") -> None:  # pragma: no cover
-    """Placeholder value.
+async def empty_send(_: "Message") -> "NoReturn":  # pragma: no cover
+    """Raise a `RuntimeError`.
+
+    Serves as a placeholder `send` function.
 
     Args:
         _: An ASGI message
@@ -56,6 +51,8 @@ async def empty_send(_: "Message") -> None:  # pragma: no cover
 
 
 class ASGIConnection(Generic[Handler, User, Auth]):
+    """The base ASGI connection container."""
+
     __slots__ = ("scope", "receive", "send", "_base_url", "_url", "_parsed_query", "_headers", "_cookies")
 
     scope: "Scope"
@@ -72,7 +69,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
     """
 
     def __init__(self, scope: "Scope", receive: "Receive" = empty_receive, send: "Send" = empty_send) -> None:
-        """The base ASGI connection container.
+        """Initialize `ASGIConnection`.
 
         Args:
             scope: The ASGI connection scope.
@@ -90,7 +87,8 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def app(self) -> "Starlite":
-        """
+        """Return the `app` for this connection.
+
         Returns:
             The [Starlite][starlite.app.Starlite] application instance
         """
@@ -98,7 +96,8 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def route_handler(self) -> Handler:
-        """
+        """Return the `route_handler` for this connection.
+
         Returns:
             The target route handler instance.
         """
@@ -106,7 +105,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def state(self) -> State:
-        """
+        """Return the `State` of this connection.
 
         Returns:
             A State instance constructed from the scope["state"] value.
@@ -115,37 +114,37 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def url(self) -> URL:
-        """
+        """Return the URL of this connection's `Scope`.
 
         Returns:
             A URL instance constructed from the request's scope.
         """
         if self._url is Empty:
-            self._url = self.scope["_url"] = URL(scope=cast("MutableMapping[str, Any]", self.scope))  # type: ignore[typeddict-item]
+            self._url = self.scope["_url"] = URL.from_scope(self.scope)  # type: ignore[typeddict-item]
         return cast("URL", self._url)
 
     @property
     def base_url(self) -> URL:
-        """
+        """Return the base URL of this connection's `Scope`.
 
         Returns:
             A URL instance constructed from the request's scope, representing only the base part
             (host + domain + prefix) of the request.
         """
         if self._base_url is Empty:
-            self._base_url = self.scope["_base_url"] = URL(  # type: ignore[typeddict-item]
-                scope={
-                    **self.scope,
-                    "path": "/",
-                    "query_string": b"",
-                    "root_path": self.scope.get("app_root_path") or self.scope.get("root_path", ""),
-                }
-            )
+            scope = {
+                **self.scope,
+                "path": "/",
+                "query_string": b"",
+                "root_path": self.scope.get("app_root_path") or self.scope.get("root_path", ""),
+            }
+            self._base_url = self.scope["_base_url"] = URL.from_scope(cast("Scope", scope))  # type: ignore[typeddict-item]
+
         return cast("URL", self._base_url)
 
     @property
     def headers(self) -> Headers:
-        """
+        """Return the headers of this connection's `Scope`.
 
         Returns:
             A Headers instance with the request's scope["headers"] value.
@@ -156,18 +155,19 @@ class ASGIConnection(Generic[Handler, User, Auth]):
         return cast("Headers", self._headers)
 
     @property
-    def query_params(self) -> Dict[str, List[str]]:
-        """
+    def query_params(self) -> QueryMultiDict:
+        """Return the query parameters of this connection's `Scope`.
+
         Returns:
             A normalized dict of query parameters. Multiple values for the same key are returned as a list.
         """
         if self._parsed_query is Empty:
-            self._parsed_query = self.scope["_parsed_query"] = parse_query_params(self.scope.get("query_string", b""))  # type: ignore[typeddict-item]
-        return cast("Dict[str, List[str]]", self._parsed_query)
+            self._parsed_query = self.scope["_parsed_query"] = QueryMultiDict.from_query_string(self.scope.get("query_string", b"").decode("utf-8"))  # type: ignore[typeddict-item]
+        return cast("QueryMultiDict", self._parsed_query)
 
     @property
     def path_params(self) -> Dict[str, Any]:
-        """
+        """Return the `path_params` of this connection's `Scope`.
 
         Returns:
             A string keyed dictionary of path parameter values.
@@ -176,7 +176,8 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def cookies(self) -> Dict[str, str]:
-        """
+        """Return the `cookies` of this connection's `Scope`.
+
         Returns:
             Returns any cookies stored in the header as a parsed dictionary.
         """
@@ -190,7 +191,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def client(self) -> Optional[Address]:
-        """
+        """Return the `client` data of this connection's `Scope`.
 
         Returns:
             A two tuple of the host name and port number.
@@ -200,7 +201,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def auth(self) -> Auth:
-        """Allows access to auth data.
+        """Return the `auth` data of this connection's `Scope`.
 
         Raises:
             ImproperlyConfiguredException: If 'auth' is not set in scope via an 'AuthMiddleware', raises an exception
@@ -214,7 +215,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def user(self) -> User:
-        """Allows access to user data.
+        """Return the `user` data of this connection's `Scope`.
 
         Raises:
             ImproperlyConfiguredException: If 'user' is not set in scope via an 'AuthMiddleware', raises an exception
@@ -228,7 +229,8 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def session(self) -> Dict[str, Any]:
-        """
+        """Return the session for this connection if a session was previously set in the `Scope`
+
         Returns:
             A dictionary representing the session value - if existing.
 
@@ -243,7 +245,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def logger(self) -> "Logger":
-        """
+        """Return the `Logger` instance for this connection.
 
         Returns:
             A 'Logger' instance.
@@ -255,7 +257,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def cache(self) -> "Cache":
-        """
+        """Return the `Cache` for this connection.
 
         Returns:
             A 'Cache' instance.
@@ -263,7 +265,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
         return self.app.cache
 
     def set_session(self, value: Union[Dict[str, Any], "BaseModel", "EmptyType"]) -> None:
-        """Helper method to set the session in scope.
+        """Set the session in the connection's `Scope`.
 
         If the [Starlite SessionMiddleware][starlite.middleware.session.SessionMiddleware] is
         enabled, the session will be added to the response as a cookie header.
@@ -277,7 +279,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
         self.scope["session"] = value
 
     def clear_session(self) -> None:
-        """Helper method to remove the session from scope.
+        """Remove the session from the connection's `Scope`.
 
         If the [Starlite SessionMiddleware][starlite.middleware.session.SessionMiddleware] is
         enabled, this will cause the session data to be cleared.
@@ -288,14 +290,14 @@ class ASGIConnection(Generic[Handler, User, Auth]):
         self.scope["session"] = Empty
 
     def url_for(self, name: str, **path_parameters: Dict[str, Any]) -> str:
-        """
+        """Return the url for a given route handler name.
 
         Args:
             name: The 'name' of the request route handler.
             **path_parameters: Values for path parameters in the route
 
         Raises:
-            NoRouteMatchFoundException: If route with 'name' does not exist, path parameters are missing in **path_parameters or have wrong type.
+            NoRouteMatchFoundException: If route with 'name' does not exist, path parameters are missing or have a wrong type.
 
         Returns:
             A string representing the absolute url of the route handler.
@@ -303,11 +305,10 @@ class ASGIConnection(Generic[Handler, User, Auth]):
         starlite_instance = self.scope["app"]
         url_path = starlite_instance.route_reverse(name, **path_parameters)
 
-        return URLPath(url_path).make_absolute_url(self.base_url)
+        return make_absolute_url(url_path, self.base_url)
 
     def url_for_static_asset(self, name: str, file_path: str) -> str:
-        """Receives a static files handler name, an asset file path and returns
-        resolved absolute url to the asset.
+        """Receives a static files handler name, an asset file path and returns resolved absolute url to the asset.
 
         Args:
             name: A static handler unique name.
@@ -322,4 +323,4 @@ class ASGIConnection(Generic[Handler, User, Auth]):
         starlite_instance = self.scope["app"]
         url_path = starlite_instance.url_for_static_asset(name, file_path)
 
-        return URLPath(url_path).make_absolute_url(self.base_url)
+        return make_absolute_url(url_path, self.base_url)
