@@ -4,6 +4,7 @@ from typing import (
     Dict,
     Generic,
     List,
+    Literal,
     Optional,
     Tuple,
     Union,
@@ -26,9 +27,6 @@ from starlite.status_codes import WS_1000_NORMAL_CLOSURE
 from starlite.utils.serialization import default_serializer
 
 if TYPE_CHECKING:
-
-    from typing_extensions import Literal
-
     from starlite.handlers.websocket import WebsocketRouteHandler  # noqa: F401
     from starlite.types import Message, Serializer, WebSocketScope
     from starlite.types.asgi_types import WebSocketDisconnectEvent  # nopycln: import
@@ -46,10 +44,9 @@ if TYPE_CHECKING:
 DISCONNECT_MESSAGE = "connection is disconnected"
 
 
-class WebSocket(
-    Generic[User, Auth],
-    ASGIConnection["WebsocketRouteHandler", User, Auth],
-):
+class WebSocket(Generic[User, Auth], ASGIConnection["WebsocketRouteHandler", User, Auth]):
+    """The Starlite WebSocket class."""
+
     __slots__ = ("connection_state",)
 
     scope: "WebSocketScope"
@@ -66,7 +63,7 @@ class WebSocket(
     """
 
     def __init__(self, scope: "Scope", receive: "Receive" = empty_receive, send: "Send" = empty_send) -> None:
-        """The Starlite WebSocket class.
+        """Initialize `WebSocket`.
 
         Args:
             scope: The ASGI connection scope.
@@ -74,10 +71,10 @@ class WebSocket(
             send: The ASGI send function.
         """
         super().__init__(scope, self.receive_wrapper(receive), self.send_wrapper(send))
-        self.connection_state: "Literal['init', 'connect', 'receive', 'disconnect']" = "init"
+        self.connection_state: Literal["init", "connect", "receive", "disconnect"] = "init"
 
     def receive_wrapper(self, receive: "Receive") -> "Receive":
-        """Wraps 'receive' to set 'self.connection_state' and validate events.
+        """Wrap 'receive' to set 'self.connection_state' and validate events.
 
         Args:
             receive: The ASGI receive function.
@@ -101,7 +98,7 @@ class WebSocket(
         return wrapped_receive
 
     def send_wrapper(self, send: "Send") -> "Send":
-        """Wraps 'send' to ensure that state is not disconnected.
+        """Wrap 'send' to ensure that state is not disconnected.
 
         Args:
             send: The ASGI send function.
@@ -122,8 +119,7 @@ class WebSocket(
         subprotocols: Optional[str] = None,
         headers: Optional[Union[Headers, Dict[str, Any], List[Tuple[bytes, bytes]]]] = None,
     ) -> None:
-        """Accepts the incoming connection. This method should be called before
-        receiving data.
+        """Accept the incoming connection. This method should be called before receiving data.
 
         Args:
             subprotocols: Websocket sub-protocol to use.
@@ -150,8 +146,8 @@ class WebSocket(
             await self.send(event)
 
     async def close(self, code: int = WS_1000_NORMAL_CLOSURE, reason: Optional[str] = None) -> None:
-        """
-        Sends an 'websocket.close' event.
+        """Send an 'websocket.close' event.
+
         Args:
             code: Status code.
             reason: Reason for closing the connection
@@ -163,7 +159,7 @@ class WebSocket(
         await self.send(event)
 
     @overload
-    async def receive_data(self, mode: "Literal['text']") -> str:
+    async def receive_data(self, mode: Literal["text"]) -> str:
         """Overload of receive_data.
 
         Args:
@@ -174,7 +170,7 @@ class WebSocket(
         """
 
     @overload
-    async def receive_data(self, mode: "Literal['binary']") -> bytes:
+    async def receive_data(self, mode: Literal["binary"]) -> bytes:
         """Overload of receive_data.
 
         Args:
@@ -184,9 +180,8 @@ class WebSocket(
             A byte-string.
         """
 
-    async def receive_data(self, mode: "Literal['binary', 'text']") -> Union[str, bytes]:
-        """Receive an 'websocket.receive' event and returns the data stored on
-        it.
+    async def receive_data(self, mode: Literal["binary", "text"]) -> Union[str, bytes]:
+        """Receive an 'websocket.receive' event and returns the data stored on it.
 
         Args:
             mode: The respective event key to use.
@@ -204,7 +199,7 @@ class WebSocket(
         return event.get("text") or "" if mode == "text" else event.get("bytes") or b""
 
     async def receive_text(self) -> str:
-        """Receives data as text.
+        """Receive data as text.
 
         Returns:
             A string.
@@ -212,7 +207,7 @@ class WebSocket(
         return await self.receive_data(mode="text")
 
     async def receive_bytes(self) -> bytes:
-        """Receives data as bytes.
+        """Receive data as bytes.
 
         Returns:
             A byte-string.
@@ -221,9 +216,9 @@ class WebSocket(
 
     async def receive_json(
         self,
-        mode: "Literal['text', 'binary']" = "text",
+        mode: Literal["text", "binary"] = "text",
     ) -> Any:
-        """Receives data and loads it into JSON using orson.
+        """Receive data and loads it into JSON using orson.
 
         Args:
             mode: Either 'text' or 'binary'.
@@ -235,9 +230,9 @@ class WebSocket(
         return loads(data)
 
     async def send_data(
-        self, data: Union[str, bytes], mode: "Literal['text', 'binary']" = "text", encoding: str = "utf-8"
+        self, data: Union[str, bytes], mode: Literal["text", "binary"] = "text", encoding: str = "utf-8"
     ) -> None:
-        """Sends a 'websocket.send' event.
+        """Send a 'websocket.send' event.
 
         Args:
             data: Data to send.
@@ -258,14 +253,16 @@ class WebSocket(
 
     @overload
     async def send_text(self, data: bytes, encoding: str = "utf-8") -> None:
+        """Overload."""
         ...
 
     @overload
     async def send_text(self, data: str) -> None:
+        """Overload."""
         ...
 
     async def send_text(self, data: Union[str, bytes], encoding: str = "utf-8") -> None:
-        """Sends data using the 'text' key of the send event.
+        """Send data using the 'text' key of the send event.
 
         Args:
             data: Data to send
@@ -278,14 +275,16 @@ class WebSocket(
 
     @overload
     async def send_bytes(self, data: bytes) -> None:
+        """Overload."""
         ...
 
     @overload
     async def send_bytes(self, data: str, encoding: str = "utf-8") -> None:
+        """Overload."""
         ...
 
     async def send_bytes(self, data: Union[str, bytes], encoding: str = "utf-8") -> None:
-        """Sends data using the 'bytes' key of the send event.
+        """Send data using the 'bytes' key of the send event.
 
         Args:
             data: Data to send
@@ -299,17 +298,18 @@ class WebSocket(
     async def send_json(
         self,
         data: Any,
-        mode: "Literal['text', 'binary']" = "text",
+        mode: Literal["text", "binary"] = "text",
         encoding: str = "utf-8",
         serializer: "Serializer" = default_serializer,
     ) -> None:
-        """Sends data as JSON.
+        """Send data as JSON.
 
         Args:
             data: A value to serialize.
             mode: Either 'text' or 'binary'.
             encoding: Encoding to use for binary data.
             serializer: A serializer function.
+
         Returns:
             None
         """
