@@ -20,6 +20,7 @@ from multidict import CIMultiDict, CIMultiDictProxy, MultiMapping
 from pydantic import BaseModel, Extra, Field, ValidationError, validator
 from typing_extensions import Annotated
 
+from starlite.datastructures.multi_dicts import MultiMixin
 from starlite.exceptions import ImproperlyConfiguredException
 
 if TYPE_CHECKING:
@@ -32,13 +33,16 @@ def _encode_headers(headers: Iterable[Tuple[str, str]]) -> "RawHeadersList":
     return [(key.lower().encode("latin-1"), value.encode("latin-1")) for key, value in headers]
 
 
-class Headers(CIMultiDictProxy[str]):
-    def __init__(self, headers: Optional[Union[Mapping[str, str], "RawHeadersList", MultiMapping]] = None) -> None:
-        """An immutable, case-insensitive for HTTP headers.
+class Headers(CIMultiDictProxy[str], MultiMixin[str]):
+    """An immutable, case-insensitive for HTTP headers.
 
-        Notes:
-            - This class inherits from [multidict](https://multidict.aio-
-                libs.org/en/stable/multidict.html#cimultidictproxy).
+    Notes:
+        - This class inherits from [multidict](https://multidict.aio-
+            libs.org/en/stable/multidict.html#cimultidictproxy).
+    """
+
+    def __init__(self, headers: Optional[Union[Mapping[str, str], "RawHeadersList", MultiMapping]] = None) -> None:
+        """Initialize `Headers`.
 
         Args:
             headers: Initial value.
@@ -55,8 +59,8 @@ class Headers(CIMultiDictProxy[str]):
 
     @classmethod
     def from_scope(cls, scope: "HeaderScope") -> "Headers":
-        """
-        Create headers from a send-message.
+        """Create headers from a send-message.
+
         Args:
             scope: The ASGI connection scope.
 
@@ -78,9 +82,13 @@ class Headers(CIMultiDictProxy[str]):
 
 
 class MutableScopeHeaders(MutableMapping):
+    """A case-insensitive, multidict-like structure that can be used to mutate headers within a.
+
+    [Scope][starlite.types.Scope]
+    """
+
     def __init__(self, scope: Optional["HeaderScope"] = None) -> None:
-        """A case-insensitive, multidict-like structure that can be used to
-        mutate headers within a [Scope][starlite.types.Scope].
+        """Initialize `MutableScopeHeaders` from a `HeaderScope`.
 
         Args:
             scope: The ASGI connection scope.
@@ -93,7 +101,7 @@ class MutableScopeHeaders(MutableMapping):
 
     @classmethod
     def from_message(cls, message: "Message") -> "MutableScopeHeaders":
-        """Constructs a header from a message object.
+        """Construct a header from a message object.
 
         Args:
             message: [Message][starlite.types.Message].
@@ -110,7 +118,7 @@ class MutableScopeHeaders(MutableMapping):
         return cls(cast("HeaderScope", message))
 
     def add(self, key: str, value: str) -> None:
-        """Adds a header to the scope.
+        """Add a header to the scope.
 
         Notes:
              - This method keeps duplicates.
@@ -150,7 +158,7 @@ class MutableScopeHeaders(MutableMapping):
         return values
 
     def extend_header_value(self, key: str, value: str) -> None:
-        """Extends a multivalued header.
+        """Extend a multivalued header.
 
         Notes:
             - A multivalues header is a header that can take a comma separated list.
@@ -199,10 +207,11 @@ class MutableScopeHeaders(MutableMapping):
             del self.headers[i]
 
     def __len__(self) -> int:
+        """Return the length of the internally stored headers, including duplicates."""
         return len(self.headers)
 
     def __iter__(self) -> Iterator[str]:
-        """iter over header names including duplicates."""
+        """Create an iterator of header names including duplicates."""
         return iter(h[0].decode("latin-1") for h in self.headers)
 
 
@@ -216,7 +225,8 @@ class Header(BaseModel, ABC):
         extra = Extra.forbid
 
         @classmethod
-        def alias_generator(cls, field_name: str) -> str:  # pylint: disable=missing-function-docstring
+        def alias_generator(cls, field_name: str) -> str:
+            """Generate field-aliases by replacing dashes with underscores in header-names."""
             return field_name.replace("_", "-")
 
     documentation_only: bool = False
@@ -225,7 +235,6 @@ class Header(BaseModel, ABC):
     @abstractmethod
     def _get_header_value(self) -> str:
         """Get the header value as string."""
-
         raise NotImplementedError
 
     @classmethod
@@ -318,9 +327,9 @@ class CacheControlHeader(Header):
 
     @classmethod
     def prevent_storing(cls) -> "CacheControlHeader":
-        """Create a `cache-control` header with the `no-store` directive which
-        indicates that any caches of any kind (private or shared) should not
-        store this response."""
+        """Create a `cache-control` header with the `no-store` directive which indicates that any caches of any kind
+        (private or shared) should not store this response.
+        """
 
         return cls(no_store=True)
 
@@ -356,8 +365,7 @@ class ETag(Header):
 
     @validator("value", always=True)
     def validate_value(cls, value: Any, values: Dict[str, Any]) -> Any:  # pylint: disable=no-self-argument
-        """Ensures that either value is set or the instance is for
-        documentation_only."""
+        """Ensure that either value is set or the instance is for documentation_only."""
         if values.get("documentation_only") or value is not None:
             return value
         raise ValueError("value must be set if documentation_only is false")
