@@ -29,8 +29,7 @@ class OpenAPIMediaType(str, Enum):
 
 
 class RequestEncodingType(str, Enum):
-    """An Enum for request 'Content-Type' header values designating encoding
-    formats."""
+    """An Enum for request 'Content-Type' header values designating encoding formats."""
 
     JSON = "application/json"
     MULTI_PART = "multipart/form-data"
