@@ -13,6 +13,11 @@ if TYPE_CHECKING:
 
 
 class ASGIRouteHandler(BaseRouteHandler["ASGIRouteHandler"]):
+    """ASGI Route Handler decorator.
+
+    Use this decorator to decorate ASGI applications.
+    """
+
     __slots__ = ("is_mount", "is_static")
 
     @validate_arguments(config={"arbitrary_types_allowed": True})
@@ -28,14 +33,14 @@ class ASGIRouteHandler(BaseRouteHandler["ASGIRouteHandler"]):
         is_static: bool = False,
         **kwargs: Any,
     ) -> None:
-        """ASGI Route Handler decorator. Use this decorator to decorate ASGI
-        apps.
+        """Initialize `ASGIRouteHandler`.
 
         Args:
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
             guards: A list of [Guard][starlite.types.Guard] callables.
             name: A string identifying the route handler.
-            opt: A string key dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
+            opt: A string key dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or
+                wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
             path: A path fragment for the route handler function or a list of path fragments. If not given defaults to '/'
             is_mount: A boolean dictating whether the handler's paths should be regarded as mount paths. Mount path accept
                 any arbitrary paths that begin with the defined prefixed path. For example, a mount with the path `/some-path/`
@@ -49,14 +54,13 @@ class ASGIRouteHandler(BaseRouteHandler["ASGIRouteHandler"]):
         super().__init__(path, exception_handlers=exception_handlers, guards=guards, name=name, opt=opt, **kwargs)
 
     def __call__(self, fn: "AnyCallable") -> "ASGIRouteHandler":
-        """Replaces a function with itself."""
+        """Replace a function with itself."""
         self.fn = fn
         self._validate_handler_function()
         return self
 
     def _validate_handler_function(self) -> None:
-        """Validates the route handler function once it's set by inspecting its
-        return annotations."""
+        """Validate the route handler function once it's set by inspecting its return annotations."""
         super()._validate_handler_function()
 
         fn = cast("AnyCallable", self.fn)
