@@ -41,10 +41,17 @@ T = TypeVar("T", bound="BaseRouteHandler")
 
 
 class ParameterConfig(BaseConfig):
+    """Base config for `ModelField`"""
+
     extra = Extra.allow
 
 
 class BaseRouteHandler(Generic[T]):
+    """Base route handler.
+
+    Serves as a subclass for all route handlers
+    """
+
     __slots__ = (
         "_resolved_dependencies",
         "_resolved_guards",
@@ -74,6 +81,19 @@ class BaseRouteHandler(Generic[T]):
         opt: Optional[Dict[str, Any]] = None,
         **kwargs: Any,
     ) -> None:
+        """Initialize `HTTPRouteHandler`.
+
+        Args:
+            path: A path fragment for the route handler function or a list of path fragments. If not given defaults to '/'
+            dependencies: A string keyed dictionary of dependency [Provider][starlite.datastructures.Provide] instances.
+            exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
+            guards: A list of [Guard][starlite.types.Guard] callables.
+            middleware: A list of [Middleware][starlite.types.Middleware].
+            name: A string identifying the route handler.
+            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or
+                wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
+            **kwargs: Any additional kwarg - will be set in the opt dictionary.
+        """
         self._resolved_dependencies: Union[Dict[str, Provide], EmptyType] = Empty
         self._resolved_guards: Union[List[Guard], EmptyType] = Empty
         self._resolved_layered_parameters: Union[Dict[str, "ModelField"], EmptyType] = Empty
@@ -95,14 +115,13 @@ class BaseRouteHandler(Generic[T]):
 
     @property
     def dependency_name_set(self) -> Set[str]:
-        """The set of all dependency names provided in the handler's ownership
-        layers."""
+        """Set of all dependency names provided in the handler's ownership layers."""
         layered_dependencies = (layer.dependencies or {} for layer in self.ownership_layers)
         return {name for layer in layered_dependencies for name in layer.keys()}
 
     @property
     def ownership_layers(self) -> List[Union[T, "Controller", "Router"]]:
-        """Returns the handler layers from the app down to the route handler.
+        """Return the handler layers from the app down to the route handler.
 
         app -> ... -> route handler
         """
@@ -116,8 +135,7 @@ class BaseRouteHandler(Generic[T]):
         return list(reversed(layers))
 
     def resolve_layered_parameters(self) -> Dict[str, "ModelField"]:
-        """Returns all parameters declared above the handler, transforming them
-        into pydantic ModelField instances."""
+        """Return all parameters declared above the handler, transforming them into pydantic ModelField instances."""
         if self._resolved_layered_parameters is Empty:
             self._resolved_layered_parameters = {}
             parameters: ParametersMap = {}
@@ -142,8 +160,7 @@ class BaseRouteHandler(Generic[T]):
         return cast("Dict[str, ModelField]", self._resolved_layered_parameters)
 
     def resolve_guards(self) -> List[Guard]:
-        """Returns all guards in the handlers scope, starting from highest to
-        current layer."""
+        """Return all guards in the handlers scope, starting from highest to current layer."""
         if self._resolved_guards is Empty:
             self._resolved_guards = []
             for layer in self.ownership_layers:
@@ -152,8 +169,7 @@ class BaseRouteHandler(Generic[T]):
         return cast("List[Guard]", self._resolved_guards)
 
     def resolve_dependencies(self) -> Dict[str, Provide]:
-        """Returns all dependencies correlating to handler function's kwargs
-        that exist in the handler's scope."""
+        """Return all dependencies correlating to handler function's kwargs that exist in the handler's scope."""
         if not self.signature_model:
             raise RuntimeError("resolve_dependencies cannot be called before a signature model has been generated")
         if self._resolved_dependencies is Empty:
@@ -167,10 +183,9 @@ class BaseRouteHandler(Generic[T]):
         return cast("Dict[str, Provide]", self._resolved_dependencies)
 
     def resolve_middleware(self) -> List["Middleware"]:
-        """Builds the middleware stack for the RouteHandler and returns it.
+        """Build the middleware stack for the RouteHandler and return it.
 
-        The middlewares are added from top to bottom (app -> router ->
-        controller -> route handler) and then reversed.
+        The middlewares are added from top to bottom (app -> router -> controller -> route handler) and then reversed.
         """
         resolved_middleware = []
         for layer in self.ownership_layers:
@@ -178,8 +193,7 @@ class BaseRouteHandler(Generic[T]):
         return list(reversed(resolved_middleware))
 
     def resolve_exception_handlers(self) -> ExceptionHandlersMap:
-        """Resolves the exception_handlers by starting from the route handler
-        and moving up.
+        """Resolve the exception_handlers by starting from the route handler and moving up.
 
         This method is memoized so the computation occurs only once.
         """
@@ -189,10 +203,10 @@ class BaseRouteHandler(Generic[T]):
         return resolved_exception_handlers
 
     def resolve_opts(self) -> None:
-        """Builds the route handler opt dictionary by going from top to bottom.
+        """Build the route handler opt dictionary by going from top to bottom.
 
-        If multiple layers define the same key, the value from the
-        closest layer to the response handler will take precedence.
+        If multiple layers define the same key, the value from the closest layer to the response handler will take
+        precedence.
         """
 
         opt: Dict[str, Any] = {}
@@ -202,15 +216,13 @@ class BaseRouteHandler(Generic[T]):
         self.opt = opt
 
     async def authorize_connection(self, connection: "ASGIConnection") -> None:
-        """Ensures the connection is authorized by running all the route guards
-        in scope."""
+        """Ensure the connection is authorized by running all the route guards in scope."""
         for guard in self.resolve_guards():
             await guard(connection, copy(self))  # type: ignore
 
     @staticmethod
     def _validate_dependency_is_unique(dependencies: Dict[str, Provide], key: str, provider: Provide) -> None:
-        """Validates that a given provider has not been already defined under a
-        different key."""
+        """Validate that a given provider has not been already defined under a different key."""
         for dependency_key, value in dependencies.items():
             if provider == value:
                 raise ImproperlyConfiguredException(
@@ -219,15 +231,15 @@ class BaseRouteHandler(Generic[T]):
                 )
 
     def _validate_handler_function(self) -> None:
-        """Validates the route handler function once set by inspecting its
-        return annotations."""
+        """Validate the route handler function once set by inspecting its return annotations."""
         if not self.fn:
             raise ImproperlyConfiguredException("Cannot call _validate_handler_function without first setting self.fn")
 
     def __str__(self) -> str:
-        """
+        """Return a unique identifier for the route handler.
+
         Returns:
-            A unique identifier for the route handler
+            A string
         """
         target = cast("Any", self.fn)
         if not hasattr(target, "__qualname__"):
