@@ -72,8 +72,9 @@ MSG_SEMANTIC_ROUTE_HANDLER_WITH_HTTP = "semantic route handlers cannot define ht
 
 
 def _normalize_cookies(local_cookies: "ResponseCookies", layered_cookies: "ResponseCookies") -> List[Dict[str, Any]]:
-    """Given two lists of cookies, ensures the uniqueness of cookies by key and
-    returns a normalized dict ready to be set on the response."""
+    """Given two lists of cookies, ensure the uniqueness of cookies by key and return a normalized dict ready to be set
+    on the response.
+    """
     filtered_cookies = [*local_cookies]
     for cookie in layered_cookies:
         if not any(c == cookie for c in filtered_cookies):
@@ -86,8 +87,7 @@ def _normalize_cookies(local_cookies: "ResponseCookies", layered_cookies: "Respo
 
 
 def _normalize_headers(headers: "ResponseHeadersMap") -> Dict[str, Any]:
-    """Given a dictionary of ResponseHeader, filters them and returns a
-    dictionary of values.
+    """Given a dictionary of ResponseHeader, filter them and return a dictionary of values.
 
     Args:
         headers: A dictionary of [ResponseHeader][starlite.datastructures.ResponseHeader] values
@@ -99,8 +99,7 @@ def _normalize_headers(headers: "ResponseHeadersMap") -> Dict[str, Any]:
 
 
 async def _normalize_response_data(data: Any, plugins: List["PluginProtocol"]) -> Any:
-    """Normalizes the response's data by awaiting any async values and
-    resolving plugins.
+    """Normalize the response's data by awaiting any async values and resolving plugins.
 
     Args:
         data: An arbitrary value
@@ -133,7 +132,7 @@ def _create_response_container_handler(
     media_type: str,
     status_code: int,
 ) -> "AsyncAnyCallable":
-    """Creates a handler function for ResponseContainers."""
+    """Create a handler function for ResponseContainers."""
 
     async def handler(data: ResponseContainer, app: "Starlite", request: "Request", **kwargs: Any) -> "ASGIApp":
         normalized_headers = {**_normalize_headers(headers), **data.headers}
@@ -155,7 +154,7 @@ def _create_response_container_handler(
 def _create_response_handler(
     after_request: Optional["AfterRequestHookHandler"], cookies: "ResponseCookies"
 ) -> "AsyncAnyCallable":
-    """Creates a handler function for Starlite Responses."""
+    """Create a handler function for Starlite Responses."""
 
     async def handler(data: Response, **kwargs: Any) -> "ASGIApp":
         normalized_cookies = _normalize_cookies(data.cookies, cookies)
@@ -169,13 +168,13 @@ def _create_response_handler(
 def _create_generic_asgi_response_handler(
     after_request: Optional["AfterRequestHookHandler"], cookies: "ResponseCookies"
 ) -> "AsyncAnyCallable":
-    """Creates a handler function for Responses."""
+    """Create a handler function for Responses."""
 
     async def handler(data: "ASGIApp", **kwargs: Any) -> "ASGIApp":
         normalized_cookies = _normalize_cookies(cookies, [])
         if hasattr(data, "set_cookie"):
             for cookie in normalized_cookies:
-                data.set_cookie(**cookie)  # type: ignore
+                data.set_cookie(**cookie)
         return await after_request(data) if after_request else data  # type: ignore
 
     return handler
@@ -190,7 +189,7 @@ def _create_data_handler(
     response_class: "ResponseType",
     status_code: int,
 ) -> "AsyncAnyCallable":
-    """Creates a handler function for arbitrary data."""
+    """Create a handler function for arbitrary data."""
 
     async def handler(data: Any, plugins: List["PluginProtocol"], **kwargs: Any) -> "ASGIApp":
         data = await _normalize_response_data(data=data, plugins=plugins)
@@ -213,7 +212,7 @@ def _create_data_handler(
 
 
 def _normalize_http_method(http_methods: Union[HttpMethod, Method, List[Union[HttpMethod, Method]]]) -> Set["Method"]:
-    """
+    """Normalize HTTP method(s) into a set of upper-case method names.
 
     Args:
         http_methods: A value for http method.
@@ -233,13 +232,13 @@ def _normalize_http_method(http_methods: Union[HttpMethod, Method, List[Union[Ht
 
 
 def _get_default_status_code(http_methods: Set["Method"]) -> int:
-    """
+    """Return the default status code for a given set of HTTP methods.
 
     Args:
-        http_methods: A set of Method strings.
+        http_methods: A set of method strings
 
     Returns:
-        A status code integer.
+        A status code
     """
     if HttpMethod.POST in http_methods:
         return HTTP_201_CREATED
@@ -249,6 +248,11 @@ def _get_default_status_code(http_methods: Set["Method"]) -> int:
 
 
 class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
+    """HTTP Route Decorator.
+
+    Use this decorator to decorate an HTTP handler with multiple methods.
+    """
+
     __slots__ = (
         "_resolved_after_response",
         "_resolved_before_request",
@@ -324,8 +328,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         tags: Optional[List[str]] = None,
         **kwargs: Any,
     ) -> None:
-        """HTTP Route Decorator. Use this decorator to decorate an HTTP handler
-        with multiple methods.
+        """Initialize `HTTPRouteHandler`.
 
         Args:
             path: A path fragment for the route handler function or a list of path fragments.
@@ -358,7 +361,8 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
                 valid IANA Media-Type.
             middleware: A list of [Middleware][starlite.types.Middleware].
             name: A string identifying the route handler.
-            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
+            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or
+                wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
             response_class: A custom subclass of [starlite.response.Response] to be used as route handler's
                 default response.
             response_cookies: A list of [Cookie](starlite.datastructures.Cookie] instances.
@@ -376,7 +380,9 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
             description: Text used for the route's schema description section.
             include_in_schema: A boolean flag dictating whether  the route handler should be documented in the OpenAPI schema.
             operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the wrapped function.
-            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation. This list should describe all exceptions raised within the route handler's function/method. The Starlite ValidationException will be added automatically for the schema if any validation is involved.
+            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation.
+                This list should describe all exceptions raised within the route handler's function/method. The Starlite
+                ValidationException will be added automatically for the schema if any validation is involved.
             response_description: Text used for the route's response schema description section.
             security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
@@ -432,14 +438,13 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         self._resolved_response_handler: Union["Callable[[Any], Awaitable[ASGIApp]]", EmptyType] = Empty
 
     def __call__(self, fn: "AnyCallable") -> "HTTPRouteHandler":
-        """Replaces a function with itself."""
+        """Replace a function with itself."""
         self.fn = fn
         self._validate_handler_function()
         return self
 
     def resolve_response_class(self) -> Type["Response"]:
-        """Returns the closest custom Response class in the owner graph or the
-        default Response class.
+        """Return the closest custom Response class in the owner graph or the default Response class.
 
         This method is memoized so the computation occurs only once.
 
@@ -452,7 +457,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         return Response
 
     def resolve_response_headers(self) -> "ResponseHeadersMap":
-        """Returns all header parameters in the scope of the handler function.
+        """Return all header parameters in the scope of the handler function.
 
         Returns:
             A dictionary mapping keys to [ResponseHeader][starlite.datastructures.ResponseHeader] instances.
@@ -474,8 +479,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         return resolved_response_headers
 
     def resolve_response_cookies(self) -> "ResponseCookies":
-        """Returns a list of Cookie instances. Filters the list to ensure each
-        cookie key is unique.
+        """Return a list of Cookie instances. Filters the list to ensure each cookie key is unique.
 
         Returns:
             A list of [Cookie][starlite.datastructures.Cookie] instances.
@@ -491,8 +495,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         return filtered_cookies
 
     def resolve_before_request(self) -> Optional["BeforeRequestHookHandler"]:
-        """Resolves the before_handler handler by starting from the route
-        handler and moving up.
+        """Resolve the before_handler handler by starting from the route handler and moving up.
 
         If a handler is found it is returned, otherwise None is set.
         This method is memoized so the computation occurs only once.
@@ -511,8 +514,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         return cast("Optional[BeforeRequestHookHandler]", self._resolved_before_request)
 
     def resolve_after_response(self) -> Optional["AfterResponseHookHandler"]:
-        """Resolves the after_response handler by starting from the route
-        handler and moving up.
+        """Resolve the after_response handler by starting from the route handler and moving up.
 
         If a handler is found it is returned, otherwise None is set.
         This method is memoized so the computation occurs only once.
@@ -534,7 +536,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
     def resolve_response_handler(
         self,
     ) -> Callable[[Any], Awaitable["ASGIApp"]]:
-        """Resolves the response_handler function for the route handler.
+        """Resolve the response_handler function for the route handler.
 
         This method is memoized so the computation occurs only once.
 
@@ -554,7 +556,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
             response_class = self.resolve_response_class()
             headers = self.resolve_response_headers()
             cookies = self.resolve_response_cookies()
-            if is_class_and_subclass(self.signature.return_annotation, ResponseContainer):  # type: ignore[misc]
+            if is_class_and_subclass(self.signature.return_annotation, ResponseContainer):  # type: ignore
                 handler = _create_response_container_handler(
                     after_request=after_request,
                     cookies=cookies,
@@ -564,7 +566,10 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
                 )
             elif is_class_and_subclass(self.signature.return_annotation, Response):
                 handler = _create_response_handler(cookies=cookies, after_request=after_request)
-            elif is_async_callable(self.signature.return_annotation):
+            elif is_async_callable(self.signature.return_annotation) or self.signature.return_annotation in {
+                ASGIApp,
+                "ASGIApp",
+            }:
                 handler = _create_generic_asgi_response_handler(cookies=cookies, after_request=after_request)
             else:
                 handler = _create_data_handler(
@@ -583,7 +588,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
     async def to_response(
         self, app: "Starlite", data: Any, plugins: List["PluginProtocol"], request: "Request"
     ) -> "ASGIApp":
-        """
+        """Return a [Response][starlite.Response] from the handler by resolving and calling it.
 
         Args:
             app: The [Starlite][starlite.app.Starlite] app instance
@@ -594,22 +599,21 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
 
         Returns:
             A Response instance
-
         """
         response_handler = self.resolve_response_handler()
         return await response_handler(app=app, data=data, plugins=plugins, request=request)  # type: ignore
 
     @property
     def signature(self) -> Signature:
-        """
+        """Return the signature of `self.fn`.
+
         Returns:
-            The Signature of 'self.fn'.
+            A `Signature`
         """
         return Signature.from_callable(cast("AnyCallable", self.fn))
 
     def _validate_handler_function(self) -> None:
-        """Validates the route handler function once it is set by inspecting
-        its return annotations."""
+        """Validate the route handler function once it is set by inspecting its return annotations."""
         super()._validate_handler_function()
 
         if self.signature.return_annotation is Signature.empty:
@@ -655,6 +659,11 @@ route = HTTPRouteHandler
 
 
 class get(HTTPRouteHandler):
+    """GET Route Decorator.
+
+    Use this decorator to decorate an HTTP handler for GET requests.
+    """
+
     @validate_arguments(config={"arbitrary_types_allowed": True})
     def __init__(
         self,
@@ -695,8 +704,7 @@ class get(HTTPRouteHandler):
         tags: Optional[List[str]] = None,
         **kwargs: Any,
     ) -> None:
-        """GET Route Decorator. Use this decorator to decorate an HTTP handler
-        for GET requests.
+        """Initialize `get`.
 
         Args:
             path: A path fragment for the route handler function or a list of path fragments.
@@ -719,13 +727,15 @@ class get(HTTPRouteHandler):
             cache_key_builder: A [cache-key builder function][starlite.types.CacheKeyBuilder]. Allows for customization
                 of the cache key if caching is configured on the application level.
             dependencies: A string keyed dictionary of dependency [Provider][starlite.datastructures.Provide] instances.
+            etag: An `etag` header of type [ETag][starlite.datastructures.ETag] that will be added to the response.
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
             guards: A list of [Guard][starlite.types.Guard] callables.
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
                 valid IANA Media-Type.
             middleware: A list of [Middleware][starlite.types.Middleware].
             name: A string identifying the route handler.
-            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
+            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or
+                wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
             response_class: A custom subclass of [starlite.response.Response] to be used as route handler's
                 default response.
             response_cookies: A list of [Cookie](starlite.datastructures.Cookie] instances.
@@ -742,7 +752,9 @@ class get(HTTPRouteHandler):
             description: Text used for the route's schema description section.
             include_in_schema: A boolean flag dictating whether  the route handler should be documented in the OpenAPI schema.
             operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the wrapped function.
-            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation. This list should describe all exceptions raised within the route handler's function/method. The Starlite ValidationException will be added automatically for the schema if any validation is involved.
+            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation.
+                This list should describe all exceptions raised within the route handler's function/method. The Starlite
+                ValidationException will be added automatically for the schema if any validation is involved.
             response_description: Text used for the route's response schema description section.
             security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
@@ -792,6 +804,11 @@ class get(HTTPRouteHandler):
 
 
 class head(HTTPRouteHandler):
+    """HEAD Route Decorator.
+
+    Use this decorator to decorate an HTTP handler for HEAD requests.
+    """
+
     @validate_arguments(config={"arbitrary_types_allowed": True})
     def __init__(
         self,
@@ -832,8 +849,7 @@ class head(HTTPRouteHandler):
         tags: Optional[List[str]] = None,
         **kwargs: Any,
     ) -> None:
-        """HEAD Route Decorator. Use this decorator to decorate an HTTP handler
-        for HEAD requests.
+        """Initialize `head`.
 
         Notes:
             - A response to a head request cannot include a body.
@@ -866,7 +882,8 @@ class head(HTTPRouteHandler):
                 valid IANA Media-Type.
             middleware: A list of [Middleware][starlite.types.Middleware].
             name: A string identifying the route handler.
-            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
+            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or
+                wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
             response_class: A custom subclass of [starlite.response.Response] to be used as route handler's
                 default response.
             response_cookies: A list of [Cookie](starlite.datastructures.Cookie] instances.
@@ -883,7 +900,9 @@ class head(HTTPRouteHandler):
             description: Text used for the route's schema description section.
             include_in_schema: A boolean flag dictating whether  the route handler should be documented in the OpenAPI schema.
             operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the wrapped function.
-            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation. This list should describe all exceptions raised within the route handler's function/method. The Starlite ValidationException will be added automatically for the schema if any validation is involved.
+            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation.
+                This list should describe all exceptions raised within the route handler's function/method. The Starlite
+                ValidationException will be added automatically for the schema if any validation is involved.
             response_description: Text used for the route's response schema description section.
             security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
@@ -932,8 +951,7 @@ class head(HTTPRouteHandler):
         )
 
     def _validate_handler_function(self) -> None:
-        """Validates the route handler function once it is set by inspecting
-        its return annotations."""
+        """Validate the route handler function once it is set by inspecting its return annotations."""
         super()._validate_handler_function()
 
         # we allow here File and FileResponse because these have special setting for head responses
@@ -948,6 +966,11 @@ class head(HTTPRouteHandler):
 
 
 class post(HTTPRouteHandler):
+    """POST Route Decorator.
+
+    Use this decorator to decorate an HTTP handler for POST requests.
+    """
+
     @validate_arguments(config={"arbitrary_types_allowed": True})
     def __init__(
         self,
@@ -988,8 +1011,7 @@ class post(HTTPRouteHandler):
         tags: Optional[List[str]] = None,
         **kwargs: Any,
     ) -> None:
-        """POST Route Decorator. Use this decorator to decorate an HTTP handler
-        for POST requests.
+        """Initialize `post`
 
         Args:
             path: A path fragment for the route handler function or a list of path fragments.
@@ -1019,7 +1041,8 @@ class post(HTTPRouteHandler):
                 valid IANA Media-Type.
             middleware: A list of [Middleware][starlite.types.Middleware].
             name: A string identifying the route handler.
-            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
+            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or
+                wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
             response_class: A custom subclass of [starlite.response.Response] to be used as route handler's
                 default response.
             response_cookies: A list of [Cookie](starlite.datastructures.Cookie] instances.
@@ -1036,7 +1059,9 @@ class post(HTTPRouteHandler):
             description: Text used for the route's schema description section.
             include_in_schema: A boolean flag dictating whether  the route handler should be documented in the OpenAPI schema.
             operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the wrapped function.
-            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation. This list should describe all exceptions raised within the route handler's function/method. The Starlite ValidationException will be added automatically for the schema if any validation is involved.
+            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI
+                documentation. This list should describe all exceptions raised within the route handler's function/method.
+                The Starlite ValidationException will be added automatically for the schema if any validation is involved.
             response_description: Text used for the route's response schema description section.
             security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
@@ -1085,6 +1110,11 @@ class post(HTTPRouteHandler):
 
 
 class put(HTTPRouteHandler):
+    """PUT Route Decorator.
+
+    Use this decorator to decorate an HTTP handler for PUT requests.
+    """
+
     @validate_arguments(config={"arbitrary_types_allowed": True})
     def __init__(
         self,
@@ -1125,8 +1155,7 @@ class put(HTTPRouteHandler):
         tags: Optional[List[str]] = None,
         **kwargs: Any,
     ) -> None:
-        """PUT Route Decorator. Use this decorator to decorate an HTTP handler
-        for PUT requests.
+        """Initialize `put`
 
         Args:
             path: A path fragment for the route handler function or a list of path fragments.
@@ -1156,7 +1185,8 @@ class put(HTTPRouteHandler):
                 valid IANA Media-Type.
             middleware: A list of [Middleware][starlite.types.Middleware].
             name: A string identifying the route handler.
-            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
+            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or
+                wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
             response_class: A custom subclass of [starlite.response.Response] to be used as route handler's
                 default response.
             response_cookies: A list of [Cookie](starlite.datastructures.Cookie] instances.
@@ -1224,6 +1254,11 @@ class put(HTTPRouteHandler):
 
 
 class patch(HTTPRouteHandler):
+    """PATCH Route Decorator.
+
+    Use this decorator to decorate an HTTP handler for PATCH requests.
+    """
+
     @validate_arguments(config={"arbitrary_types_allowed": True})
     def __init__(
         self,
@@ -1264,8 +1299,7 @@ class patch(HTTPRouteHandler):
         tags: Optional[List[str]] = None,
         **kwargs: Any,
     ) -> None:
-        """PATCH Route Decorator. Use this decorator to decorate an HTTP
-        handler for PATCH requests.
+        """Initialize `patch`.
 
         Args:
             path: A path fragment for the route handler function or a list of path fragments.
@@ -1295,7 +1329,8 @@ class patch(HTTPRouteHandler):
                 valid IANA Media-Type.
             middleware: A list of [Middleware][starlite.types.Middleware].
             name: A string identifying the route handler.
-            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
+            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or
+                wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
             response_class: A custom subclass of [starlite.response.Response] to be used as route handler's
                 default response.
             response_cookies: A list of [Cookie](starlite.datastructures.Cookie] instances.
@@ -1312,7 +1347,9 @@ class patch(HTTPRouteHandler):
             description: Text used for the route's schema description section.
             include_in_schema: A boolean flag dictating whether  the route handler should be documented in the OpenAPI schema.
             operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the wrapped function.
-            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation. This list should describe all exceptions raised within the route handler's function/method. The Starlite ValidationException will be added automatically for the schema if any validation is involved.
+            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation.
+                This list should describe all exceptions raised within the route handler's function/method. The Starlite
+                ValidationException will be added automatically for the schema if any validation is involved.
             response_description: Text used for the route's response schema description section.
             security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
@@ -1361,6 +1398,11 @@ class patch(HTTPRouteHandler):
 
 
 class delete(HTTPRouteHandler):
+    """DELETE Route Decorator.
+
+    Use this decorator to decorate an HTTP handler for DELETE requests.
+    """
+
     @validate_arguments(config={"arbitrary_types_allowed": True})
     def __init__(
         self,
@@ -1401,8 +1443,7 @@ class delete(HTTPRouteHandler):
         tags: Optional[List[str]] = None,
         **kwargs: Any,
     ) -> None:
-        """DELETE Route Decorator. Use this decorator to decorate an HTTP
-        handler for DELETE requests.
+        """Initialize `delete`
 
         Args:
             path: A path fragment for the route handler function or a list of path fragments.
@@ -1432,7 +1473,8 @@ class delete(HTTPRouteHandler):
                 valid IANA Media-Type.
             middleware: A list of [Middleware][starlite.types.Middleware].
             name: A string identifying the route handler.
-            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
+            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or
+                wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
             response_class: A custom subclass of [starlite.response.Response] to be used as route handler's
                 default response.
             response_cookies: A list of [Cookie](starlite.datastructures.Cookie] instances.
@@ -1449,7 +1491,9 @@ class delete(HTTPRouteHandler):
             description: Text used for the route's schema description section.
             include_in_schema: A boolean flag dictating whether  the route handler should be documented in the OpenAPI schema.
             operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the wrapped function.
-            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation. This list should describe all exceptions raised within the route handler's function/method. The Starlite ValidationException will be added automatically for the schema if any validation is involved.
+            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation.
+                This list should describe all exceptions raised within the route handler's function/method. The Starlite
+                ValidationException will be added automatically for the schema if any validation is involved.
             response_description: Text used for the route's response schema description section.
             security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
