@@ -26,13 +26,13 @@ from pydantic.fields import (
     Undefined,
 )
 from pydantic_factories.utils import is_optional
-from starlette.datastructures import URL
 
 from starlite.constants import (
     EXTRA_KEY_IS_PARAMETER,
     EXTRA_KEY_REQUIRED,
     RESERVED_KWARGS,
 )
+from starlite.datastructures import URL
 from starlite.datastructures.provide import Provide
 from starlite.enums import ParamType, RequestEncodingType
 from starlite.exceptions import ImproperlyConfiguredException, ValidationException
@@ -57,11 +57,12 @@ class ParameterDefinition(NamedTuple):
 
 
 class Dependency:
+    """Dependency graph of a given combination of `Route` + `RouteHandler`"""
+
     __slots__ = ("key", "provide", "dependencies")
 
     def __init__(self, key: str, provide: Provide, dependencies: List["Dependency"]) -> None:
-        """This class is used to create a dependency graph for a given
-        combination of Route + RouteHandler.
+        """Initialize a dependency.
 
         Args:
             key: The dependency key
@@ -74,8 +75,9 @@ class Dependency:
 
 
 def merge_parameter_sets(first: Set[ParameterDefinition], second: Set[ParameterDefinition]) -> Set[ParameterDefinition]:
-    """Given two sets of parameter definitions, coming from different
-    dependencies for example, merge them into a single set."""
+    """Given two sets of parameter definitions, coming from different dependencies for example, merge them into a single
+    set.
+    """
     result: Set[ParameterDefinition] = first.intersection(second)
     difference = first.symmetric_difference(second)
     for param in difference:
@@ -86,6 +88,11 @@ def merge_parameter_sets(first: Set[ParameterDefinition], second: Set[ParameterD
 
 
 class KwargsModel:
+    """Model required kwargs for a given RouteHandler and its dependencies.
+
+    This is done once and is memoized during application bootstrap, ensuring minimal runtime overhead.
+    """
+
     __slots__ = (
         "expected_cookie_params",
         "expected_dependencies",
@@ -112,10 +119,7 @@ class KwargsModel:
         sequence_query_parameter_names: Set[str],
         is_data_optional: bool,
     ) -> None:
-        """This class is used to model the required kwargs for a given
-        RouteHandler and its dependencies.
-
-        This is done once and is memoized during application bootstrap, ensuring minimal runtime overhead.
+        """Initialize `KwargsModel`.
 
         Args:
             expected_cookie_params: Any expected cookie parameter kwargs
@@ -126,6 +130,7 @@ class KwargsModel:
             expected_query_params:  Any expected query parameter kwargs
             expected_reserved_kwargs: Any expected reserved kwargs, e.g. 'state'
             sequence_query_parameter_names: Any query parameters that are sequences
+            is_data_optional: Treat data as optional
         """
         self.expected_cookie_params = expected_cookie_params
         self.expected_dependencies = expected_dependencies
@@ -154,8 +159,7 @@ class KwargsModel:
         dependencies: Dict[str, Provide],
         signature_model_fields: Dict[str, ModelField],
     ) -> Tuple[Set[ParameterDefinition], set]:
-        """This function gets parameter_definitions for the construction of
-        KwargsModel instance.
+        """Get parameter_definitions for the construction of KwargsModel instance.
 
         Args:
             path_parameters: Any expected path parameters.
@@ -245,9 +249,8 @@ class KwargsModel:
         path_parameters: Set[str],
         layered_parameters: Dict[str, ModelField],
     ) -> "KwargsModel":
-        """This function pre-determines what parameters are required for a
-        given combination of route + route handler. It is executed during the
-        application bootstrap process.
+        """Pre-determine what parameters are required for a given combination of route + route handler. It is executed
+        during the application bootstrap process.
 
         Args:
             signature_model: A [SignatureModel][starlite.signature.SignatureModel] subclass.
@@ -258,7 +261,6 @@ class KwargsModel:
         Returns:
             An instance of KwargsModel
         """
-
         cls._validate_raw_kwargs(
             path_parameters=path_parameters,
             dependencies=dependencies,
@@ -334,7 +336,7 @@ class KwargsModel:
     def _collect_reserved_kwargs(
         self, connection: Union["WebSocket", "Request"], connection_query_params: Dict[str, Union[str, List[str]]]
     ) -> Dict[str, Any]:
-        """
+        """Create and populate dictionary of "reserved" keyword arguments.
 
         Args:
             connection: An instance of [Request][starlite.connection.Request] or [WebSocket][starlite.connection.WebSocket].
@@ -363,8 +365,8 @@ class KwargsModel:
         return reserved_kwargs
 
     def to_kwargs(self, connection: Union["WebSocket", "Request"]) -> Dict[str, Any]:
-        """Return a dictionary of kwargs. Async values, i.e. CoRoutines, are
-        not resolved to ensure this function is sync.
+        """Return a dictionary of kwargs. Async values, i.e. CoRoutines, are not resolved to ensure this function is
+        sync.
 
         Args:
             connection: An instance of [Request][starlite.connection.Request] or [WebSocket][starlite.connection.WebSocket].
@@ -372,7 +374,9 @@ class KwargsModel:
         Returns:
             A string keyed dictionary of kwargs expected by the handler function and its dependencies.
         """
-        connection_query_params = {k: self._sequence_or_scalar_param(k, v) for k, v in connection.query_params.items()}
+        connection_query_params = {
+            k: self._sequence_or_scalar_param(k, v) for k, v in connection.query_params.dict().items()
+        }
 
         path_params = self._collect_params(
             params=connection.path_params, expected=self.expected_path_params, url=connection.url
@@ -399,7 +403,7 @@ class KwargsModel:
 
     @staticmethod
     def _collect_params(params: Mapping[str, Any], expected: Set[ParameterDefinition], url: URL) -> Dict[str, Any]:
-        """Collects request params, checking for missing required values."""
+        """Collect request params, checking for missing required values."""
         missing_params = [p.field_alias for p in expected if p.is_required and p.field_alias not in params]
         if missing_params:
             raise ValidationException(f"Missing required parameter(s) {', '.join(missing_params)} for url {url}")
@@ -417,8 +421,7 @@ class KwargsModel:
     async def resolve_dependency(
         self, dependency: "Dependency", connection: Union["WebSocket", "Request"], **kwargs: Any
     ) -> Any:
-        """Given an instance of [Dependency][starlite.kwargs.Dependency],
-        recursively resolves its dependency graph.
+        """Given an instance of [Dependency][starlite.kwargs.Dependency], recursively resolves its dependency graph.
 
         Args:
             dependency: An instance of [Dependency][starlite.kwargs.Dependency]
@@ -426,6 +429,7 @@ class KwargsModel:
             **kwargs: Any kwargs to pass recursively.
 
         Returns:
+            The resolved dependency value
         """
         if dependency.provide.cache_per_request:
             async with dependency.provide.lock:
@@ -441,8 +445,9 @@ class KwargsModel:
 
     @classmethod
     def _create_dependency_graph(cls, key: str, dependencies: Dict[str, Provide]) -> Dependency:
-        """Creates a graph like structure of dependencies, with each dependency
-        including its own dependencies as a list."""
+        """Create a graph like structure of dependencies, with each dependency including its own dependencies as a
+        list.
+        """
         provide = dependencies[key]
         sub_dependency_keys = [k for k in get_signature_model(provide).__fields__ if k in dependencies]
         return Dependency(
@@ -455,8 +460,9 @@ class KwargsModel:
     def _create_parameter_definition(
         allow_none: bool, field_info: FieldInfo, field_name: str, path_parameters: Set[str], is_sequence: bool
     ) -> ParameterDefinition:
-        """Creates a ParameterDefinition for the given pydantic FieldInfo
-        instance and inserts it into the correct parameter set."""
+        """Create a ParameterDefinition for the given pydantic FieldInfo instance and inserts it into the correct
+        parameter set.
+        """
         extra = field_info.extra
         is_required = extra.get(EXTRA_KEY_REQUIRED, True)
         default_value = field_info.default if field_info.default is not Undefined else None
@@ -489,8 +495,7 @@ class KwargsModel:
         expected_form_data: Optional[Tuple[RequestEncodingType, ModelField]],
         dependency_kwargs_model: "KwargsModel",
     ) -> None:
-        """Validates that the 'data' kwarg is compatible across
-        dependencies."""
+        """Validate that the 'data' kwarg is compatible across dependencies."""
         if (expected_form_data and not dependency_kwargs_model.expected_form_data) or (
             not expected_form_data and dependency_kwargs_model.expected_form_data
         ):
@@ -513,8 +518,9 @@ class KwargsModel:
         model_fields: Dict[str, ModelField],
         layered_parameters: Dict[str, ModelField],
     ) -> None:
-        """Validates that there are no ambiguous kwargs, that is, kwargs
-        declared using the same key in different places."""
+        """Validate that there are no ambiguous kwargs, that is, kwargs declared using the same key in different
+        places.
+        """
         dependency_keys = set(dependencies.keys())
 
         parameter_names = {
@@ -547,15 +553,13 @@ class KwargsModel:
             )
 
     def _sequence_or_scalar_param(self, key: str, value: List[str]) -> Union[str, List[str]]:
-        """Returns the first element of 'value' if we expect it to be a scalar
-        value (appears in self.sequence_query_parameter_names) and it contains
-        only a single element."""
+        """Return the first element of 'value' if we expect it to be a scalar value (appears in
+        self.sequence_query_parameter_names) and it contains only a single element.
+        """
         return value[0] if key not in self.sequence_query_parameter_names and len(value) == 1 else value
 
     async def _get_request_data(self, request: "Request") -> Any:
-        """
-        Retrieves the data - either json data or form data - from the request
-        """
+        """Retrieve the data - either json data or form data - from the request"""
         if self.expected_form_data:
             media_type, model_field = self.expected_form_data
             form_data = await request.form()
