@@ -1,4 +1,3 @@
-import re
 import secrets
 from abc import ABC, abstractmethod
 from typing import (
@@ -9,8 +8,8 @@ from typing import (
     Dict,
     Generic,
     List,
+    Literal,
     Optional,
-    Pattern,
     Type,
     TypeVar,
     Union,
@@ -19,12 +18,14 @@ from typing import (
 
 from orjson import OPT_SERIALIZE_NUMPY, dumps, loads
 from pydantic import BaseConfig, BaseModel, PrivateAttr, conint, conlist, constr
-from typing_extensions import Literal
 
 from starlite import ASGIConnection, Cookie, DefineMiddleware
 from starlite.datastructures import MutableScopeHeaders
 from starlite.middleware.base import MiddlewareProtocol
-from starlite.middleware.utils import should_bypass_middleware
+from starlite.middleware.utils import (
+    build_exclude_path_pattern,
+    should_bypass_middleware,
+)
 from starlite.types import Empty
 from starlite.utils import default_serializer, get_serializer_from_scope
 
@@ -40,13 +41,13 @@ BaseSessionBackendT = TypeVar("BaseSessionBackendT", bound="BaseSessionBackend")
 
 
 class BaseBackendConfig(BaseModel):
-    _backend_class: Type["BaseSessionBackend"] = PrivateAttr()
-
-    """Configuration for Session middleware cookies."""
+    """Configuration for Session middleware backends."""
 
     class Config(BaseConfig):
         arbitrary_types_allowed = True
 
+    _backend_class: Type["BaseSessionBackend"] = PrivateAttr()
+
     key: constr(min_length=1, max_length=256) = "session"  # type: ignore[valid-type]
     """
     Key to use for the cookie inside the header,
@@ -77,11 +78,9 @@ class BaseBackendConfig(BaseModel):
 
     @property
     def middleware(self) -> DefineMiddleware:
-        """Use this property to insert the config into a middleware list on one
-        of the application layers.
+        """Use this property to insert the config into a middleware list on one of the application layers.
 
         Examples:
-
             ```python
             from os import urandom
 
@@ -106,6 +105,8 @@ class BaseBackendConfig(BaseModel):
 
 
 class ServerSideSessionConfig(BaseBackendConfig):
+    """Base configuration for server side backends."""
+
     session_id_bytes: int = 32
     """
     Number of bytes used to generate a random session-ID
@@ -113,15 +114,20 @@ class ServerSideSessionConfig(BaseBackendConfig):
 
 
 class BaseSessionBackend(ABC, Generic[ConfigT]):
+    """Abstract session backend defining the interface between a storage mechanism and the.
+
+    [SessionMiddleware][starlite.middleware.session.SessionMiddleware].
+
+    This serves as the base class for all client- and server-side backends
+    """
+
     __slots__ = ("config",)
 
     def __init__(self, config: ConfigT) -> None:
-        """Abstract session backend defining the interface between a storage
-        mechanism and the [SessionMiddleware][
-        starlite.middleware.session.SessionMiddleware].
+        """Initialize `BaseSessionBackend`
 
-        This serves as the base class for all client- and server-side
-        backends
+        Args:
+            config: A instance of a subclass of `BaseBackendConfig`
         """
         self.config = config
 
@@ -159,7 +165,7 @@ class BaseSessionBackend(ABC, Generic[ConfigT]):
     async def store_in_message(
         self, scope_session: "ScopeSession", message: "Message", connection: ASGIConnection
     ) -> None:
-        """Stores the necessary information in the outgoing `Message`
+        """Store the necessary information in the outgoing `Message`
 
         Args:
             scope_session: Current session to store
@@ -172,8 +178,8 @@ class BaseSessionBackend(ABC, Generic[ConfigT]):
 
     @abstractmethod
     async def load_from_connection(self, connection: ASGIConnection) -> Dict[str, Any]:
-        """Load session data from a connection and return it as a dictionary to
-        be used in the current application scope.
+        """Load session data from a connection and return it as a dictionary to be used in the current application
+        scope.
 
         Args:
             connection: An ASGIConnection instance
@@ -188,13 +194,19 @@ class BaseSessionBackend(ABC, Generic[ConfigT]):
 
 
 class ServerSideBackend(Generic[ServerConfigT], BaseSessionBackend[ServerConfigT]):
+    """Base class for server-side backends.
+
+    Implements [BaseSessionBackend][starlite.middleware.session.base.BaseSessionBackend] and defines and
+    interface which subclasses can implement to facilitate the storage of session data
+    """
+
     __slots__ = ()
 
     def __init__(self, config: ServerConfigT) -> None:
-        """Base class for server-side backends. Implements.
+        """Initialize `ServerSideBackend`
 
-        [BaseSessionBackend][starlite.middleware.session.base.BaseSessionBackend] and defines and
-        interface which subclasses can implement to facilitate the storage of session data
+        Args:
+            config: A subclass of `ServerSideSessionConfig`
         """
         super().__init__(config=config)
 
@@ -226,8 +238,7 @@ class ServerSideBackend(Generic[ServerConfigT], BaseSessionBackend[ServerConfigT
 
     @abstractmethod
     async def delete(self, session_id: str) -> None:
-        """Delete the data associated with `session_id`. Fails silently if no
-        such session-ID exists.
+        """Delete the data associated with `session_id`. Fails silently if no such session-ID exists.
 
         Args:
             session_id: The session-ID
@@ -246,8 +257,7 @@ class ServerSideBackend(Generic[ServerConfigT], BaseSessionBackend[ServerConfigT
 
     def generate_session_id(self) -> str:
         """Generate a new session-ID, with n=[session_id_bytes][starlite.middle
-        ware.session.base.ServerSideSessionConfig.session_id_bytes] random
-        bytes.
+        ware.session.base.ServerSideSessionConfig.session_id_bytes] random bytes.
 
         Returns:
             A session-ID
@@ -257,13 +267,12 @@ class ServerSideBackend(Generic[ServerConfigT], BaseSessionBackend[ServerConfigT
     async def store_in_message(
         self, scope_session: "ScopeSession", message: "Message", connection: ASGIConnection
     ) -> None:
-        """Stores the necessary information in the outgoing `Message` by
-        setting a cookie containing the session-ID. If the session is empty, a
-        null-cookie will be set. Otherwise, the serialised data will be stored
-        using [set][starlite.middleware.session.base.ServerSideBackend.set],
-        under the current session-id. If no session-ID exists, a new ID will be
-        generated using [generate_session_id][starlite.middleware.session.base.
-        ServerSideBackend.generate_session_id].
+        """Store the necessary information in the outgoing `Message` by setting a cookie containing the session-ID.
+
+        If the session is empty, a null-cookie will be set. Otherwise, the serialised
+        data will be stored using [set][starlite.middleware.session.base.ServerSideBackend.set],
+        under the current session-id. If no session-ID exists, a new ID will be generated using
+        [generate_session_id][starlite.middleware.session.base.ServerSideBackend.generate_session_id].
 
         Args:
             scope_session: Current session to store
@@ -299,8 +308,8 @@ class ServerSideBackend(Generic[ServerConfigT], BaseSessionBackend[ServerConfigT
             headers["Set-Cookie"] = Cookie(value=session_id, key=self.config.key, **cookie_params).to_header(header="")
 
     async def load_from_connection(self, connection: ASGIConnection) -> Dict[str, Any]:
-        """Load session data from a connection and return it as a dictionary to
-        be used in the current application scope.
+        """Load session data from a connection and return it as a dictionary to be used in the current application
+        scope.
 
         The session-ID will be gathered from a cookie with the key set in the
         [configuration][starlite.middleware.session.base.BaseBackendConfig.key]. If
@@ -326,10 +335,12 @@ class ServerSideBackend(Generic[ServerConfigT], BaseSessionBackend[ServerConfigT
 
 
 class SessionMiddleware(MiddlewareProtocol, Generic[BaseSessionBackendT]):
+    """Starlite session middleware for storing session data."""
+
     __slots__ = ("backend", "_exclude_pattern", "_exclude_opt_key")
 
     def __init__(self, app: "ASGIApp", backend: BaseSessionBackendT) -> None:
-        """Starlite session middleware for storing session data.
+        """Initialize `SessionMiddleware`
 
         Args:
             app: An ASGI application
@@ -339,16 +350,12 @@ class SessionMiddleware(MiddlewareProtocol, Generic[BaseSessionBackendT]):
 
         self.app = app
         self.backend = backend
-        self._exclude_pattern: Optional[Pattern[str]] = None
+        self._exclude_pattern = build_exclude_path_pattern(exclude=backend.config.exclude)
         self._exclude_opt_key = backend.config.exclude_opt_key
 
-        if backend.config.exclude:
-            exclude = backend.config.exclude
-            self._exclude_pattern = re.compile("|".join(exclude)) if isinstance(exclude, list) else re.compile(exclude)
-
     def create_send_wrapper(self, connection: ASGIConnection) -> Callable[["Message"], Awaitable[None]]:
-        """
-        Creates a wrapper for the ASGI send function, which handles setting the cookies on the outgoing response.
+        """Create a wrapper for the ASGI send function, which handles setting the cookies on the outgoing response.
+
         Args:
             connection: ASGIConnection
 
@@ -357,8 +364,9 @@ class SessionMiddleware(MiddlewareProtocol, Generic[BaseSessionBackendT]):
         """
 
         async def wrapped_send(message: "Message") -> None:
-            """A wrapper around the send function, declared in local scope to
-            use closure values.
+            """Wrap the `send` function.
+
+            Declared in local scope to make use of closure values.
 
             Args:
                 message: An ASGI message.
@@ -378,7 +386,8 @@ class SessionMiddleware(MiddlewareProtocol, Generic[BaseSessionBackendT]):
         return wrapped_send
 
     async def __call__(self, scope: "Scope", receive: "Receive", send: "Send") -> None:
-        """
+        """ASGI-callable.
+
         Args:
             scope: The ASGI connection scope.
             receive: The ASGI receive function.
