@@ -4,6 +4,7 @@ from typing import (
     Dict,
     Generic,
     List,
+    Literal,
     Optional,
     Tuple,
     TypeVar,
@@ -27,7 +28,6 @@ from starlite.utils.helpers import get_enum_string_value
 from starlite.utils.serialization import default_serializer
 
 if TYPE_CHECKING:
-    from typing_extensions import Literal
 
     from starlite.datastructures import BackgroundTask, BackgroundTasks
     from starlite.types import (
@@ -43,6 +43,8 @@ T = TypeVar("T")
 
 
 class Response(Generic[T]):
+    """Base Starlite HTTP response class, used as the basis for all other response classes."""
+
     __slots__ = (
         "status_code",
         "media_type",
@@ -67,8 +69,7 @@ class Response(Generic[T]):
         encoding: str = "utf-8",
         is_head_response: bool = False,
     ) -> None:
-        """This is the base Starlite HTTP response class, used as the basis for
-        all other response classes.
+        """Initialize the response.
 
         Args:
             content: A value for the response body that will be rendered into bytes string.
@@ -104,9 +105,9 @@ class Response(Generic[T]):
         domain: Optional[str] = None,
         secure: bool = False,
         httponly: bool = False,
-        samesite: 'Literal["lax", "strict", "none"]' = "lax",
+        samesite: Literal["lax", "strict", "none"] = "lax",
     ) -> None:
-        """Sets a cookie on the response.
+        """Ses a cookie on the response.
 
         Args:
             key: Key for the cookie.
@@ -137,7 +138,7 @@ class Response(Generic[T]):
         )
 
     def set_header(self, key: str, value: str) -> None:
-        """Sets a header on the response.
+        """Set a header on the response.
 
         Args:
             key: Header key.
@@ -149,7 +150,7 @@ class Response(Generic[T]):
         self.headers[key] = value
 
     def set_etag(self, etag: Union[str, "ETag"]) -> None:
-        """Sets an etag header.
+        """Set an etag header.
 
         Args:
             etag: An etag value.
@@ -165,7 +166,7 @@ class Response(Generic[T]):
         path: str = "/",
         domain: Optional[str] = None,
     ) -> None:
-        """Deletes a cookie.
+        """Delete a cookie.
 
         Args:
             key: Key of the cookie.
@@ -181,7 +182,7 @@ class Response(Generic[T]):
 
     @staticmethod
     def serializer(value: Any) -> Any:
-        """Serializer hook for orjson to handle pydantic models.
+        """Return a serializer for orjson to handle pydantic models.
 
         Args:
             value: A value to serialize
@@ -193,8 +194,8 @@ class Response(Generic[T]):
         return default_serializer(value)
 
     def render(self, content: Any) -> bytes:
-        """
-        Handles the rendering of content T into a bytes string.
+        """Handle the rendering of content T into a bytes string.
+
         Args:
             content: A value for the response body that will be rendered into bytes string.
 
@@ -229,7 +230,7 @@ class Response(Generic[T]):
 
     @property
     def content_length(self) -> Optional[int]:
-        """
+        """Content length of the response if applicable.
 
         Returns:
             The content length of the body (e.g. for use in a "Content-Length" header).
@@ -241,7 +242,8 @@ class Response(Generic[T]):
 
     @property
     def encoded_headers(self) -> List[Tuple[bytes, bytes]]:
-        """
+        """Response headers as a list of tuples of bytes.
+
         Notes:
             - A 'Content-Length' header will be added if appropriate and not provided by the user.
 
@@ -265,7 +267,7 @@ class Response(Generic[T]):
         return encoded_headers
 
     async def after_response(self) -> None:
-        """Executed after the response is sent.
+        """Execute after the response is sent.
 
         Returns:
             None
@@ -274,8 +276,8 @@ class Response(Generic[T]):
             await self.background()
 
     async def start_response(self, send: "Send") -> None:
-        """
-        Emits the start event of the response. This event includes the headers and status codes.
+        """Emit the start event of the response. This event includes the headers and status codes.
+
         Args:
             send: The ASGI send function.
 
@@ -291,7 +293,7 @@ class Response(Generic[T]):
         await send(event)
 
     async def send_body(self, send: "Send", receive: "Receive") -> None:  # pylint: disable=unused-argument
-        """Emits the response body.
+        """Emit the response body.
 
         Args:
             send: The ASGI send function.
@@ -307,7 +309,7 @@ class Response(Generic[T]):
         await send(event)
 
     async def __call__(self, scope: "Scope", receive: "Receive", send: "Send") -> None:
-        """The call method of the response is an "ASGIApp".
+        """ASGI callable of the `Response`.
 
         Args:
             scope: The ASGI connection scope.
