@@ -6,8 +6,6 @@ from pathlib import Path
 from typing import TYPE_CHECKING, List, Optional, Tuple, Union
 from uuid import UUID
 
-from typing_extensions import TypedDict
-
 from starlite.exceptions import ImproperlyConfiguredException
 from starlite.kwargs import KwargsModel
 from starlite.signature import get_signature_model
@@ -35,12 +33,12 @@ param_type_map = {
 }
 
 
-class RouteHandlerIndex(TypedDict):
-    name: str
-    handler: "BaseRouteHandler"
-
-
 class BaseRoute(ABC):
+    """Base Route class used by Starlite.
+
+    It's an abstract class meant to be extended.
+    """
+
     __slots__ = (
         "app",
         "handler_names",
@@ -60,14 +58,13 @@ class BaseRoute(ABC):
         scope_type: "ScopeType",
         methods: Optional[List["Method"]] = None,
     ) -> None:
-        """This is the base Route class used by Starlite. It's an abstract
-        class meant to be extended.
+        """Initialize the route.
 
         Args:
-            handler_names:
-            path:
-            scope_type:
-            methods:
+            handler_names: Names of the associated handlers
+            path: Base path of the route
+            scope_type: Type of the ASGI scope
+            methods: Supported methods
         """
         self.path, self.path_format, self.path_components = self._parse_path(path)
         self.path_parameters: List[PathParameterDefinition] = [
@@ -76,12 +73,10 @@ class BaseRoute(ABC):
         self.handler_names = handler_names
         self.scope_type = scope_type
         self.methods = set(methods or [])
-        if "GET" in self.methods:
-            self.methods.add("HEAD")
 
     @abstractmethod
     async def handle(self, scope: "Scope", receive: "Receive", send: "Send") -> None:  # pragma: no cover
-        """The route's ASGI App.
+        """ASGI App of the route.
 
         Args:
             scope: The ASGI connection scope.
@@ -94,7 +89,7 @@ class BaseRoute(ABC):
         raise NotImplementedError("Route subclasses must implement handle which serves as the ASGI app entry point")
 
     def create_handler_kwargs_model(self, route_handler: "BaseRouteHandler") -> KwargsModel:
-        """Method to create a KwargsModel for a given route handler."""
+        """Create a `KwargsModel` for a given route handler."""
         dependencies = route_handler.resolve_dependencies()
         signature_model = get_signature_model(route_handler)
 
@@ -113,8 +108,7 @@ class BaseRoute(ABC):
 
     @staticmethod
     def _validate_path_parameter(param: str) -> None:
-        """Validates that a path parameter adheres to the required format and
-        datatypes.
+        """Validate that a path parameter adheres to the required format and datatypes.
 
         Raises:
             ImproperlyConfiguredException: If the parameter has an invalid format.
@@ -133,7 +127,7 @@ class BaseRoute(ABC):
 
     @classmethod
     def _parse_path(cls, path: str) -> Tuple[str, str, List[Union[str, PathParameterDefinition]]]:
-        """Normalizes and parses a path.
+        """Normalize and parse a path.
 
         Splits the path into a list of components, parsing any that are path parameters. Also builds the OpenAPI
         compatible path, which does not include the type of the path parameters.
