@@ -22,6 +22,8 @@ if TYPE_CHECKING:
 
 
 class WebSocketRoute(BaseRoute):
+    """A websocket route, handling a single `WebsocketRouteHandler`"""
+
     __slots__ = (
         "route_handler",
         "handler_parameter_model",
@@ -33,7 +35,7 @@ class WebSocketRoute(BaseRoute):
         path: str,
         route_handler: "WebsocketRouteHandler",
     ) -> None:
-        """This class handles a single Websocket Route.
+        """Initialize the route.
 
         Args:
             path: The path for the route.
@@ -48,8 +50,7 @@ class WebSocketRoute(BaseRoute):
         )
 
     async def handle(self, scope: "WebSocketScope", receive: "Receive", send: "Send") -> None:  # type: ignore[override]
-        """ASGI app that creates a WebSocket from the passed in args, and then
-        awaits the handler function.
+        """ASGI app that creates a WebSocket from the passed in args, and then awaits the handler function.
 
         Args:
             scope: The ASGI connection scope.
@@ -72,7 +73,7 @@ class WebSocketRoute(BaseRoute):
             await fn(**kwargs)
 
     async def _resolve_kwargs(self, websocket: "WebSocket[Any, Any]") -> Dict[str, Any]:
-        """Resolves the required kwargs from the request data.
+        """Resolve the required kwargs from the request data.
 
         Args:
             websocket: WebSocket instance
