@@ -34,8 +34,8 @@ from starlite.utils import (
 
 if TYPE_CHECKING:
     from pydantic.error_wrappers import ErrorDict
-    from starlette.datastructures import URL
 
+    from starlite.datastructures import URL
     from starlite.types import AnyCallable
 
 
@@ -45,6 +45,8 @@ SKIP_VALIDATION_NAMES = {"request", "socket", "state", "scope"}
 
 
 class SignatureModel(BaseModel):
+    """Pydantic model representing a signature."""
+
     class Config(BaseConfig):
         arbitrary_types_allowed = True
 
@@ -56,13 +58,11 @@ class SignatureModel(BaseModel):
     def parse_values_from_connection_kwargs(
         cls, connection: Union[Request, WebSocket], **kwargs: Any
     ) -> Dict[str, Any]:
-        """Given a dictionary of values extracted from the connection, create
-        an instance of the given SignatureModel subclass and return the parsed
-        values.
+        """Given a dictionary of values extracted from the connection, create an instance of the given SignatureModel
+        subclass and return the parsed values.
 
-        This is not equivalent to calling the '.dict'  method of the
-        pydantic model, because it doesn't convert nested values into
-        dictionary, just extracts the data from the signature model
+        This is not equivalent to calling the '.dict'  method of the pydantic model, because it doesn't convert nested
+        values into dictionary, just extracts the data from the signature model
         """
         try:
             signature = cls(**kwargs)
@@ -71,8 +71,7 @@ class SignatureModel(BaseModel):
             raise cls.construct_exception(connection, exc) from exc
 
     def resolve_field_value(self, key: str) -> Any:
-        """Given a field key, return value using plugin mapping, if
-        available."""
+        """Given a field key, return value using plugin mapping, if available."""
         value = self.__getattribute__(key)  # pylint: disable=unnecessary-dunder-call
         mapping = self.field_plugin_mappings.get(key)
         return mapping.get_model_instance_for_value(value) if mapping else value
@@ -81,19 +80,16 @@ class SignatureModel(BaseModel):
     def construct_exception(
         cls, connection: Union[Request, WebSocket], exc: ValidationError
     ) -> Union[InternalServerException, ValidationException]:
-        """Distinguish between validation errors that arise from parameters and
-        dependencies.
+        """Distinguish between validation errors that arise from parameters and dependencies.
 
         If both parameter and dependency values are invalid, we raise the client error first.
 
-        Parameters
-        ----------
-        connection : Request | WebSocket
-        exc : ValidationError
+        Args:
+            connection: A Request or WebSocket
+            exc: A ValidationError
 
-        Returns
-        -------
-        ValidationException | InternalServerException
+        Returns:
+            A ValidationException or InternalServerException
         """
         server_errors: List["ErrorDict"] = []
         client_errors: List["ErrorDict"] = []
@@ -124,17 +120,7 @@ class SignatureModel(BaseModel):
 
 
 class SignatureParameter:
-    """Represents the parameters of a callable for purpose of signature model
-    generation.
-
-    Parameters
-    ----------
-    fn_name : str
-        Name of function.
-    parameter_name : str
-        Name of parameter.
-    parameter : inspect.Parameter
-    """
+    """Represents the parameters of a callable for purpose of signature model generation."""
 
     __slots__ = (
         "annotation",
@@ -149,6 +135,13 @@ class SignatureParameter:
     optional: bool
 
     def __init__(self, fn_name: str, parameter_name: str, parameter: Parameter) -> None:
+        """Initialize SignatureParameter.
+
+        Args:
+            fn_name: Name of function.
+            parameter_name: Name of parameter.
+            parameter: inspect.Parameter
+        """
         if parameter.annotation is Signature.empty:
             raise ImproperlyConfiguredException(
                 f"Kwarg {parameter_name} of {fn_name} does not have a type annotation. If it "
@@ -161,40 +154,23 @@ class SignatureParameter:
 
     @property
     def default_defined(self) -> bool:
-        """`True` if `self.default` is not one of the undefined sentinel types.
-
-        Returns
-        -------
-        bool
-        """
+        """Return a boolean, indicating if `self.default` is not one of the undefined sentinel types."""
         return self.default not in UNDEFINED_SENTINELS
 
 
 class SignatureModelFactory:
-    """Utility class for constructing the signature model and grouping
-    associated state.
+    """Utility class for constructing the signature model and grouping associated state.
 
     Instance available at `SignatureModel.factory`.
 
-    Parameters
-    ----------
-    fn : AnyCallable
-    plugins : list[PluginProtocol]
-    dependency_names : Set[str]
-
     The following attributes are populated after the `model()` method has been called to generate
     the `SignatureModel` subclass.
 
-    Attributes
-    ----------
-    field_plugin_mappings : dict[str, PluginMapping]
-        Maps parameter name, to `PluginMapping` where a plugin has been applied.
-    field_definitions : dict[str, Tuple[Any, Any]
-        Maps parameter name to the `(<type>, <default>)` tuple passed to `pydantic.create_model()`.
-    defaults : dict[str, Any]
-        Maps parameter name to default value, if one defined.
-    dependency_name_set : set[str]
-        The names of all known dependency parameters.
+    Attributes:
+        field_plugin_mappings: Maps parameter name, to `PluginMapping` where a plugin has been applied.
+        field_definitions:  Maps parameter name to the `(<type>, <default>)` tuple passed to `pydantic.create_model()`.
+        defaults: Maps parameter name to default value, if one defined.
+        dependency_name_set: The names of all known dependency parameters.
     """
 
     __slots__ = (
@@ -208,6 +184,13 @@ class SignatureModelFactory:
     )
 
     def __init__(self, fn: "AnyCallable", plugins: List["PluginProtocol"], dependency_names: Set[str]) -> None:
+        """Initialise `SignatureModelFactory`
+
+        Args:
+            fn: A callable
+            plugins: A list of plugins
+            dependency_names: Dependency names
+        """
         if fn is None:
             raise ImproperlyConfiguredException("Parameter `fn` to `SignatureModelFactory` cannot be `None`.")
         self.signature = Signature.from_callable(fn)
@@ -219,18 +202,14 @@ class SignatureModelFactory:
         self.dependency_name_set = dependency_names
 
     def check_for_unprovided_dependency(self, parameter: SignatureParameter) -> None:
-        """Where a dependency has been explicitly marked using the `Dependency`
-        function, it is a configuration error if that dependency has been
-        defined without a default value, and it hasn't been provided to the
-        handler.
+        """Where a dependency has been explicitly marked using the `Dependency` function, it is a configuration error if
+        that dependency has been defined without a default value, and it hasn't been provided to the handler.
 
-        Parameters
-        ----------
-        parameter : SignatureParameter
+        Args:
+            parameter  SignatureParameter
 
-        Raises
-        ------
-        `ImproperlyConfiguredException`
+        Raises:
+            `ImproperlyConfiguredException`
         """
         if parameter.optional:
             return
@@ -246,39 +225,32 @@ class SignatureModelFactory:
             )
 
     def collect_dependency_names(self, parameter: SignatureParameter) -> None:
-        """Add parameter name of dependencies declared using `Dependency()`
-        function to the set of all dependency names.
+        """Add parameter name of dependencies declared using `Dependency()` function to the set of all dependency names.
 
-        Parameters
-        ----------
-        parameter : SignatureParameter
+        Args:
+            parameter: SignatureParameter
         """
         if is_dependency_field(parameter.default):
             self.dependency_name_set.add(parameter.name)
 
     def set_field_default(self, parameter: SignatureParameter) -> None:
-        """If `parameter` has defined default, map it to the parameter name in
-        `self.defaults`.
+        """If `parameter` has defined default, map it to the parameter name in `self.defaults`.
 
-        Parameters
-        ----------
-        parameter : SignatureParameter
+        Args:
+            parameter: SignatureParameter
         """
         if parameter.default_defined:
             self.defaults[parameter.name] = parameter.default
 
     def get_type_annotation_from_plugin(self, parameter: SignatureParameter, plugin: PluginProtocol) -> Any:
-        """Use plugin declared for parameter annotation type to generate a
-        pydantic model.
+        """Use plugin declared for parameter annotation type to generate a pydantic model.
 
-        Parameters
-        ----------
-        parameter : SignatureParameter
-        plugin : PluginProtocol
+        Args:
+            parameter:  SignatureParameter
+            plugin: PluginProtocol
 
-        Returns
-        -------
-        Any
+        Returns:
+            A pydantic model to be used as a type
         """
         type_args = get_args(parameter.annotation)
         type_value = type_args[0] if type_args else parameter.annotation
@@ -290,16 +262,13 @@ class SignatureModelFactory:
 
     @staticmethod
     def create_field_definition_from_parameter(parameter: SignatureParameter) -> Tuple[Any, Any]:
-        """Construct an `(<annotation>, <default>)` tuple, appropriate for
-        `pydantic.create_model()`.
+        """Construct an `(<annotation>, <default>)` tuple, appropriate for `pydantic.create_model()`.
 
-        Parameters
-        ----------
-        parameter : SignatureParameter
+        Args:
+            parameter: SignatureParameter
 
-        Returns
-        -------
-        tuple[Any, Any]
+        Returns:
+            tuple[Any, Any]
         """
         if parameter.default_defined:
             return parameter.annotation, parameter.default
@@ -309,21 +278,18 @@ class SignatureModelFactory:
 
     @property
     def signature_parameters(self) -> Generator[SignatureParameter, None, None]:
-        """Iterable of `SignatureModel` instances, that represent the
-        parameters of the function signature that should be included in the
-        `SignatureModel` type.
+        """Create a generator of `SignatureParameters` to be included in the `SignatureModel` by iterating over the
+        parameters of the function signature.
 
-        Returns
-        -------
-        Generator[SignatureParameter, None, None]
+        Returns:
+            Generator[SignatureParameter, None, None]
         """
         for name, parameter in filter(lambda x: x[0] not in SKIP_NAMES, self.signature.parameters.items()):
             yield SignatureParameter(self.fn_name, name, parameter)
 
     @staticmethod
     def should_skip_parameter_validation(parameter: SignatureParameter) -> bool:
-        """Identify dependencies for which provided values should not be
-        validated.
+        """Identify dependencies for which provided values should not be validated.
 
         Args:
             parameter (SignatureParameter): A parameter to be added to the signature model.
@@ -334,12 +300,10 @@ class SignatureModelFactory:
         return parameter.name in SKIP_VALIDATION_NAMES or should_skip_dependency_validation(parameter.default)
 
     def create_signature_model(self) -> Type[SignatureModel]:
-        """Constructs a `SignatureModel` type that represents the signature of
-        `self.fn`
+        """Construct a `SignatureModel` type that represents the signature of `self.fn`
 
-        Returns
-        -------
-        type[SignatureModel]
+        Returns:
+            type[SignatureModel]
         """
         try:
             for parameter in self.signature_parameters:
@@ -371,8 +335,7 @@ class SignatureModelFactory:
 
 
 def get_signature_model(value: Any) -> Type[SignatureModel]:
-    """Helper function to retrieve and validate the signature model from a
-    provider or handler."""
+    """Retrieve and validate the signature model from a provider or handler."""
     try:
         return cast("Type[SignatureModel]", value.signature_model)
     except AttributeError as e:  # pragma: no cover
