@@ -10,6 +10,7 @@ from typing import (
     Iterable,
     Iterator,
     List,
+    Literal,
     Set,
     Tuple,
     Type,
@@ -17,8 +18,6 @@ from typing import (
     Union,
 )
 
-from typing_extensions import Literal
-
 from starlite.enums import ScopeType
 
 from .asgi_types import ASGIApp
