@@ -6,22 +6,21 @@ T = TypeVar("T")
 
 
 def get_name(value: Any) -> str:
-    """Helper to get the '__name__' dunder of a value.
+    """Get the `__name__` of an object.
 
     Args:
-        value: An arbitrary value.
+        value: An arbitrary object.
 
     Returns:
         A name string.
     """
-
     if hasattr(value, "__name__"):
         return cast("str", value.__name__)
     return type(value).__name__
 
 
 def get_enum_string_value(value: Union[Enum, str]) -> str:
-    """A helper function to return the string value of a string enum.
+    """Return the string value of a string enum.
 
     See: https://github.com/starlite-api/starlite/pull/633#issuecomment-1286519267
 
