@@ -25,8 +25,8 @@ T = TypeVar("T")
 
 
 def is_async_callable(value: Callable[P, T]) -> TypeGuard[Callable[P, Awaitable[T]]]:
-    """Extends `asyncio.iscoroutinefunction()` to additionally detect async
-    `partial` objects and class instances with `async def __call__()` defined.
+    """Extend `asyncio.iscoroutinefunction()` to additionally detect async `partial` objects and class instances with
+    `async def __call__()` defined.
 
     Args:
         value: Any
@@ -41,22 +41,22 @@ def is_async_callable(value: Callable[P, T]) -> TypeGuard[Callable[P, Awaitable[
 
 
 class AsyncCallable(Generic[P, T]):
+    """Wrap a callable into an asynchronous callable."""
+
     __slots__ = ("args", "kwargs", "wrapped_callable", "is_method", "num_expected_args")
 
     def __init__(self, fn: Callable[P, T]) -> None:
-        """Utility class that wraps a callable and ensures it can be called as
-        an async function.
+        """Initialize the wrapper from any callable.
 
         Args:
             fn: Callable to wrap - can be any sync or async callable.
         """
-
         self.is_method = ismethod(fn) or (callable(fn) and ismethod(fn.__call__))  # type: ignore
         self.num_expected_args = len(getfullargspec(fn).args) - (1 if self.is_method else 0)
         self.wrapped_callable = Ref[Callable](fn if is_async_callable(fn) else async_partial(fn))  # pyright: ignore
 
     async def __call__(self, *args: P.args, **kwargs: P.kwargs) -> T:
-        """A proxy to the wrapped function's call method.
+        """Proxy the wrapped function's call method.
 
         Args:
             *args: Args of the wrapped function.
@@ -69,8 +69,8 @@ class AsyncCallable(Generic[P, T]):
 
 
 def as_async_callable_list(value: Union[Callable, List[Callable]]) -> List[AsyncCallable]:
-    """
-    Helper function to handle wrapping values in AsyncCallables
+    """Wrap callables in `AsyncCallable`s.
+
     Args:
         value: A callable or list of callables.
 
@@ -83,8 +83,9 @@ def as_async_callable_list(value: Union[Callable, List[Callable]]) -> List[Async
 
 
 def async_partial(fn: Callable) -> Callable:
-    """This function wraps a given sync function making it async. In difference
-    to the 'asyncio.run_sync' function, it allows for passing kwargs.
+    """Wrap a given sync function making it async.
+
+    In difference to the 'asyncio.run_sync' function, it allows for passing kwargs.
 
     Args:
         fn: A sync callable to wrap.
@@ -101,11 +102,12 @@ def async_partial(fn: Callable) -> Callable:
 
 
 class AsyncIteratorWrapper(Generic[T]):
+    """Asynchronous generator, wrapping an iterable or iterator."""
+
     __slots__ = ("iterator", "generator")
 
     def __init__(self, iterator: Union[Iterator[T], Iterable[T]]) -> None:
-        """Take a sync iterator or iterable and yields values from it
-        asynchronously.
+        """Take a sync iterator or iterable and yields values from it asynchronously.
 
         Args:
             iterator: A sync iterator or iterable.
